@@ -23,5 +23,5 @@
 
 DATADIR = "${prefix}/share"
 DATADIR = DATADIR.replace(
-    "${prefix}", "/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install")
+    "${prefix}", "/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install")
 VERSION = "2.34.3"
