@@ -310,6 +310,14 @@ class Map:
         try: newmap = self._interpolate_to_grid1(grid_shape,spacing,self.origin)
         except: newmap = self._interpolate_to_grid(grid_shape,spacing,self.origin)
         return newmap
+    
+        #use this function to downsample map
+    def downsample_map(self,spacing,grid_shape=None):
+      apix_ratio = self.apix/spacing
+      if grid_shape is None:
+          grid_shape = int(round(self.z_size()*apix_ratio)),int(round(self.y_size()*apix_ratio)),int(round(self.x_size()*apix_ratio))
+      emmap_1 = self._interpolate_to_grid(grid_shape,spacing,self.origin)
+      return emmap_1
   
     # find background peak
     def _peak_density(self):
