@@ -8,10 +8,8 @@
 #
 
 import os
-import shutil
-import json
+import math
 from ccpem_core.ccpem_utils import ccpem_argparser
-from ccpem_core import ccpem_utils
 from ccpem_core import process_manager
 from ccpem_core.tasks import task_utils
 from ccpem_core.ccpem_utils.spherical_angles_distribution import angle_distn
@@ -22,7 +20,7 @@ class DockEM(task_utils.CCPEMTask):
     CCPEM DockEM task.
     '''
     task_info = task_utils.CCPEMTaskInfo(
-        name='Dock-EM',
+        name='DockEM',
         author='Roseman, AM',
         version='2.0',
         description=(
@@ -67,12 +65,10 @@ class DockEM(task_utils.CCPEMTask):
                                      pipeline=pipeline,
                                      job_location=job_location,
                                      parent=parent)
-        self.roi_crop_map = None
-
         # Reset specific args to None (used when 'new' window is called)
-        self.args.search_object_map.value = None
-        self.args.search_object_filtered.value = None
-        self.args.search_object_mask.value = None
+#         self.args.search_object_map.value = None
+#         self.args.search_object_filtered.value = None
+#         self.args.search_object_mask.value = None
 
     def parser(self):
         parser = ccpem_argparser.ccpemArgParser()
@@ -86,6 +82,18 @@ class DockEM(task_utils.CCPEMTask):
             type=str,
             default=None)
         #
+        stage = parser.add_argument_group()
+        stage.add_argument(
+            '-stage',
+            '--stage',
+            help='Store progress of job',
+            choices=['Ready',
+                     'Setup',
+                     'Search'],
+            metavar='Stage',
+            type=str,
+            default='Ready')
+        #
         run_search = parser.add_argument_group()
         run_search.add_argument(
             '-run_search',
@@ -178,6 +186,15 @@ class DockEM(task_utils.CCPEMTask):
             type=str,
             default=None)
         #
+        roi_map = parser.add_argument_group()
+        roi_map.add_argument(
+            '-roi_map',
+            '--roi_map',
+            help=('ROI map to show area of search'),
+            metavar='Region of interest map',
+            type=str,
+            default=None)
+        #
         theta_step = parser.add_argument_group()
         theta_step.add_argument(
             '-s',
@@ -187,7 +204,18 @@ class DockEM(task_utils.CCPEMTask):
                   'in Euler angles convention, in spider document format.'),
             metavar='Theta sampling',
             type=float,
-            default=10.0)
+            default=8.0)
+        #
+        theta_limit = parser.add_argument_group()
+        theta_limit.add_argument(
+            '-theta_limit',
+            '--theta_limit',
+            help=('The value of theta limit is 0 to 180 deg.  180 is the '
+                  'full search used by default.  Smaller values can be '
+                  'used to restrict model orientations in the search '),
+            metavar='Theta limit',
+            type=float,
+            default=180.0)
         #
         angl_sampling = parser.add_argument_group()
         angl_sampling.add_argument(
@@ -196,7 +224,7 @@ class DockEM(task_utils.CCPEMTask):
             help=('Angular sampling increment for the omega search (deg).'),
             type=float,
             metavar='Angular sampling',
-            default=10.0)
+            default=8.0)
         #
         angl_filename = parser.add_argument_group()
         angl_filename.add_argument(
@@ -328,7 +356,9 @@ class DockEM(task_utils.CCPEMTask):
 
         # Reset n_proc dependant on number of items in angular sweep
         if self.args.n_proc() != 0:
-            angles = angle_distn(self.args.theta_step(), write_output=False)
+            angles = angle_distn(theta_step=self.args.theta_step(),
+                                 theta_limit=self.args.theta_limit(),
+                                 write_output=False)
             n_proc = min(len(angles), self.args.n_proc())
             self.args.n_proc.value = n_proc
 
@@ -531,10 +561,6 @@ centre_model_in_map.AlignMapModel(
             stdin=stdin,
             stdout=stdout,
             stderr=stderr)
-        # Output
-        self.roi_crop_map = os.path.join(
-            self.job_location,
-            'local_cropmap{0}.mrc'.format(self.job_str))
         return self.dockemsoln_process
 
     def stdin_roi(self):
@@ -563,25 +589,24 @@ centre_model_in_map.AlignMapModel(
         out += str(self.args.box_extent.value) + ',0' + '\n'
         return out
 
+    def calculate_theta_sampling(self):
+        '''
+        Calculate theta sampling based on map resolution and angular
+        sampling
+        '''
+        if all([self.args.map_resolution(), self.args.box_extent()]):
+            theta = (self.args.map_resolution() / self.args.box_extent() / 4.0) * 180 / math.pi
+            return int(theta)
+        else:
+            return None
+
     def run_pipeline(self, job_id=None, run=True, db_inject=None):
         '''
         Run pipeline to prepare input files.
         '''
-        # If re-running prep phase remove directory...
-        remove_data = False
-        try:
-            if not self.args.run_search() and self.job_location is not None:
-                path = os.path.join(self.job_location,
-                                    'task.ccpem')
-                if os.path.exists(path):
-                    status = json.load(open(path))['status']
-                    print 'Status : ', status
-                    if status != 'ready':
-                        remove_data = True
-            if remove_data:
-                shutil.rmtree(self.job_location)
-        except OSError:
-            ccpem_utils.print_warning(message='DockEM: error removing old data')
+        self.validate_args()
+        
+        self.args.stage.value = 'Setup'
 
         # Set Job number based on job location
         path = self.job_location
@@ -599,9 +624,10 @@ centre_model_in_map.AlignMapModel(
             if job_num > 999:
                 self.job_str = self.job_str[-3:]
         self.args.job_prefix.value = self.job_str
-        # Save args to include prefix
-        self.args.output_args_as_json(os.path.join(self.job_location,
-                                                   'args.json'))
+        # Set ROI map
+        self.args.roi_map.value = os.path.join(
+            self.job_location,
+            'local_cropmap{0}.mrc'.format(self.job_str))
 
         # Set pipeline
         pl = []
@@ -614,7 +640,8 @@ centre_model_in_map.AlignMapModel(
         if self.args.centre_model():
             output_path = os.path.join(self.job_location,
                                        'centred.pdb')
-            pl.append([self.job_centre_model_in_map(output_path=output_path)])
+            pl.append(
+                [self.job_centre_model_in_map(output_path=output_path)])
             self.args.search_object.value = output_path
         pl.append([self.job_make_density()])
         # 3) Map filer - mapfpdb
@@ -623,7 +650,8 @@ centre_model_in_map.AlignMapModel(
         pl.append([self.job_mask_convolute()])
         # ## Part B - Run DockEM search
         # 5) Generate angular sampling file
-        angle_distn(theta_step=self.args.theta_step.value,
+        angle_distn(theta_step=self.args.theta_step(),
+                    theta_limit=self.args.theta_limit(),
                     output_path=self.job_location)
         # 6) DockEM Region of interest
         job_roi = self.job_roi()
@@ -641,8 +669,9 @@ centre_model_in_map.AlignMapModel(
             # Run local search in parallel multi-process mode
             else:
                 for n in xrange(self.args.n_proc.value):
-                    job_lsv = self.job_dockemlsv(n_proc=self.args.n_proc.value,
-                                                 proc=n+1)
+                    job_lsv = self.job_dockemlsv(
+                        n_proc=self.args.n_proc.value,
+                        proc=n+1)
                     jobs_lsv.append(job_lsv)
             # 7) DockEM LSV
             # Merge parallel jobs if required
@@ -658,6 +687,11 @@ centre_model_in_map.AlignMapModel(
             pl.append([job_peak])
             # 9) DockEM Soln
             pl.append([job_soln])
+            self.args.stage.value = 'Search'
+
+        # Save args to include ROI and stage
+        self.args.output_args_as_json(
+            os.path.join(self.job_location,'args.json'))
 
         self.pipeline = process_manager.CCPEMPipeline(
             pipeline=pl,
@@ -681,7 +715,8 @@ centre_model_in_map.AlignMapModel(
         out = self.args.target_map.value + '\n'
         out += str(self.args.grid_sampling.value) + '\n'
         out += str(self.args.map_resolution.value) + ',' + str(self.args.high_pass_filter.value) + '\n'
-        out += self.args.target_map_filtered.value + '\n'
+        if self.args.target_map_filtered() is not None:
+            out += self.args.target_map_filtered.value + '\n'
         return out
 
     def write_stdin_make_density(self):
@@ -774,13 +809,3 @@ centre_model_in_map.AlignMapModel(
         out += '1,' + str(self.args.number_solutions.value) + '\n'
         out += self.args.search_object.value + '\n'
         return out
-
-def main():
-    '''
-    Run task
-    '''
-    task_utils.command_line_task_launch(
-        task=DockEM)
-
-if __name__ == '__main__':
-    main()
