@@ -52,6 +52,7 @@ class Refmac(task_utils.CCPEMTask):
                 'libg': settings.which(program='libg')
                 }
 
+
     def __init__(self,
                  database_path=None,
                  args=None,
@@ -360,6 +361,14 @@ class Refmac(task_utils.CCPEMTask):
             metavar='Auto weight',
             type=bool,
             default=True)
+#
+        parser.add_argument(
+            '-symmetry_auto',
+            '--symmetry_auto',
+            help=('Automatically detect and apply symmetry (recommended)'),
+            metavar='Auto symmetry',
+            type=bool,
+            default=True)
         #
         parser.add_argument(
             '-map_sharpen',
@@ -372,7 +381,7 @@ class Refmac(task_utils.CCPEMTask):
         parser.add_argument(
             '-set_bfactor_on',
             '--set_bfactor_on',
-            help='Reset all atomic B factors to given value on input',
+            help='Reset all atomic B-factors to given value on input',
             metavar='Set B-factor',
             type=bool,
             default=True)
@@ -380,7 +389,7 @@ class Refmac(task_utils.CCPEMTask):
         parser.add_argument(
             '-set_bfactor',
             '--set_bfactor',
-            help='Set all input atomic B factors to this value',
+            help='Set all input atomic B-factors to this value',
             metavar='B-factor',
             type=float,
             default=40.0)
@@ -529,7 +538,6 @@ class Refmac(task_utils.CCPEMTask):
 
                 return
 
-
         # Convert map to mtz
         self.process_maptomtz = RefmacMapToMtz(
             command=self.commands['refmac'],
@@ -623,6 +631,7 @@ class Refmac(task_utils.CCPEMTask):
                     sharp=self.args.map_sharpen.value,
                     weight=self.args.weight.value,
                     weight_auto=self.args.weight_auto.value,
+                    symmetry_auto=self.args.symmetry_auto.value,
                     set_bfactor=self.args.set_bfactor_on.value,
                     atom_bfactor=self.args.set_bfactor.value,
                     atomsf_path=self.atomsf,
@@ -645,6 +654,7 @@ class Refmac(task_utils.CCPEMTask):
                 self.process_shift_back = RefmacShiftBack(
                     command=self.commands['refmac'],
                     name='Shift back to map frame',
+                    lib_path=self.args.lib_in.value,
                     job_location=self.job_location,
                     pdb_path=self.process_refine.pdbout_path,
                     atomsf_path=self.atomsf)
@@ -661,6 +671,7 @@ class Refmac(task_utils.CCPEMTask):
                     name='Refmac refine (global)',
                     weight=self.args.weight.value,
                     weight_auto=self.args.weight_auto.value,
+                    symmetry_auto=self.args.symmetry_auto.value,
                     sharp=self.args.map_sharpen.value,
                     set_bfactor=self.args.set_bfactor_on.value,
                     atom_bfactor=self.args.set_bfactor.value,
@@ -732,6 +743,7 @@ class Refmac(task_utils.CCPEMTask):
                     sharp=self.args.map_sharpen.value,
                     weight=self.args.weight.value,
                     weight_auto=self.args.weight_auto.value,
+                    symmetry_auto=self.args.symmetry_auto.value,
                     set_bfactor=self.args.set_bfactor_on.value,
                     atom_bfactor=self.args.set_bfactor.value,
                     name='Refmac refine (HM1)',
@@ -851,7 +863,8 @@ class PDBSetCell(object):
         self.map_path = ccpem_utils.get_path_abs(map_path)
         self.pdbout_path = os.path.join(self.job_location,
                                              'pdbset.pdb')
-
+        self.cell_info = None
+        self.stdin = None
         #
         self.get_cell_parameters()
         self.set_stdin()
@@ -867,23 +880,25 @@ class PDBSetCell(object):
             stdin=self.stdin)
 
     def get_cell_parameters(self):
-        map_header = numpy_mrc_io.read_mrc(self.map_path, header_only=True)
-        self.cell_info = [map_header['xlen'],
-                          map_header['ylen'],
-                          map_header['zlen'],
-                          map_header['alpha'],
-                          map_header['beta'],
-                          map_header['gamma']]
+        if os.path.exists(path=self.map_path):
+            map_header = numpy_mrc_io.read_mrc(self.map_path, header_only=True)
+            self.cell_info = [map_header['xlen'],
+                              map_header['ylen'],
+                              map_header['zlen'],
+                              map_header['alpha'],
+                              map_header['beta'],
+                              map_header['gamma']]
 
     def set_args(self):
         self.args = ['xyzin', self.pdb_path]
         self.args += ['xyzout', self.pdbout_path]
 
     def set_stdin(self):
-        self.stdin = 'CELL '
-        for p in self.cell_info:
-            self.stdin += ' {0}'.format(p)
-        self.stdin += '\nend'
+        if self.cell_info is not None:
+            self.stdin = 'CELL '
+            for p in self.cell_info:
+                self.stdin += ' {0}'.format(p)
+            self.stdin += '\nend'
 
 
 class LibgRestraints(object):
@@ -898,7 +913,7 @@ class LibgRestraints(object):
                  w='',
                  u=''):
         self.job_location = ccpem_utils.get_path_abs(job_location)
-        self.pdb_path = ccpem_utils.get_path_abs(pdb_path)
+        self.pdb_path = pdb_path
         self.w = w
         self.u = u
 
@@ -961,7 +976,7 @@ class RefmacMapToMtz(object):
                  on_finish_custom=None):
         self.command = command
         self.job_location = job_location
-        self.map_path = ccpem_utils.get_path_abs(map_path)
+        self.map_path = map_path
         self.resolution = resolution
         self.refmap_path = refmap_path
         self.mode = mode
@@ -1022,13 +1037,13 @@ class RefmacMapToMtz(object):
         if self.mode == 'Local':
             self.stdin += '\nsfcalc mrad {0}'.format(self.mrad)
             self.stdin += '\nsfcalc shift'
-        if self.blur_array is not None:
+        if self.blur_array is not None and len(self.blur_array) > 0:
             blur_str = '\nsfcalc blur'
             for b in self.blur_array:
                 if b is not None:
                     blur_str += ' {0}'.format(b)
             self.stdin += blur_str
-        if self.sharp_array is not None:
+        if self.sharp_array is not None and len(self.sharp_array) > 0:
             if self.sharp_array[0] is not None:
                 sharp_str = '\nsfcalc sharp'
                 for b in self.sharp_array:
@@ -1143,6 +1158,7 @@ class RefmacRefine(object):
                  vector_diff_map=False,
                  weight=0.0001,
                  weight_auto=True,
+                 symmetry_auto=True,
                  keywords=None,
                  libg_restraints=False,
                  libg_restraints_path=None,
@@ -1180,6 +1196,7 @@ class RefmacRefine(object):
         self.atom_bfactor = atom_bfactor
         self.weight = weight
         self.weight_auto = weight_auto
+        self.symmetry_auto = symmetry_auto
         self.jelly_body_on = jelly_body_on
         self.jelly_body_sigma = jelly_body_sigma
         self.jelly_body_dmax = jelly_body_dmax
@@ -1249,6 +1266,8 @@ class RefmacRefine(object):
         else:
             if self.weight is not None:
                 self.stdin += '\nweight matrix {0}'.format(self.weight)
+        if self.symmetry_auto:
+            self.stdin += '\nncsr global'
         if self.set_bfactor and self.atom_bfactor is not None:
             self.stdin += '\nBFACtor SET {0}'.format(self.atom_bfactor)
         self.stdin += '\nreso {0}'.format(self.resolution)
@@ -1288,6 +1307,8 @@ class RefmacRefine(object):
             self.stdin += '\n' + self.keywords
         self.stdin += '\nend'
 
+
+
 class RefmacSfcalcCrd(object):
     '''
     Calculate sfcalc (mtz) from coordinate input.
@@ -1296,9 +1317,11 @@ class RefmacSfcalcCrd(object):
     def __init__(self,
                  job_location,
                  pdb_path,
+                 lib_in=None,
                  resolution=None):
         self.job_location = job_location
         self.pdb_path = pdb_path
+        self.lib_in = lib_in
         self.resolution = resolution
         self.name = self.__class__.__name__
 
@@ -1314,6 +1337,8 @@ class RefmacSfcalcCrd(object):
 
     def set_args(self):
         self.args = ['xyzin', self.pdb_path]
+        if self.lib_in is not None:
+            self.args += ['lib_in', self.lib_in]
 
     def set_stdin(self):
         self.stdin = 'mode sfcalc'
@@ -1332,12 +1357,14 @@ class RefmacShiftBack(object):
                  job_location,
                  pdb_path,
                  mtz_path=None,
+                 lib_path=None,
                  pdbout_path=None,
                  name=None,
                  atomsf_path=None):
         self.command = command
         self.job_location = job_location
         self.pdb_path = pdb_path
+        self.lib_path = lib_path
         self.pdbout_path = pdbout_path
         self.mtz_path = mtz_path
         if self.mtz_path is None:
@@ -1362,6 +1389,8 @@ class RefmacShiftBack(object):
     def set_args(self):
         self.args = ['xyzin', self.pdb_path]
         self.args += ['hklin', self.mtz_path]
+        if self.lib_path is not None:
+            self.args += ['libin', self.lib_path]
         if self.pdbout_path is None:
             self.pdbout_path = os.path.join(self.job_location,
                                             'refined.pdb')
@@ -1578,14 +1607,3 @@ class DivideAndConquer(object):
         if self.keywords is not None:
             self.stdin += '\n' + self.keywords
         self.stdin += '\nend\n'
-
-
-def main():
-    '''
-    Run task
-    '''
-    task_utils.command_line_task_launch(
-        task=Refmac)
-
-if __name__ == '__main__':
-    main()
