@@ -11,6 +11,7 @@
 CCP-EM main window.
 '''
 
+
 import sys
 import os
 from PyQt4 import QtGui
@@ -37,7 +38,6 @@ try:
 except ImportError:
     modeller_available = False
 
-
 class CCPEMProjectWindow(QtGui.QMainWindow):
     '''
     Window to show job view and project manager
@@ -102,7 +102,11 @@ class CCPEMMainWindow(QtGui.QMainWindow):
     '''
     Main window class to hold job history and task launch buttons.
     '''
-    def __init__(self, splash=None, args=None, parent=None):
+    def __init__(self,
+                 splash=None, 
+                 show_warning=True,
+                 args=None,
+                 parent=None):
         super(CCPEMMainWindow, self).__init__(parent)
         self.args = args
         self.database = None
@@ -130,20 +134,20 @@ class CCPEMMainWindow(QtGui.QMainWindow):
 
         # Check if CCP4 is present
         ccp4_warnings = self.tasks.check_ccp4_environment()
-        if ccp4_warnings is not None:
-            if splash is not None:
-                splash.close()
-            print 'trigger warning'
-            self.show_ccp4_not_found()
 
-        # Show task errors
-        if self.tasks.errors:
-            if splash is not None:
-                splash.close()
-            self.show_task_errors()
+        if show_warning:
+            if ccp4_warnings is not None:
+                if splash is not None:
+                    splash.close()
+                self.show_ccp4_not_found()
+
+            # Show task errors
+            if self.tasks.errors:
+                if splash is not None:
+                    splash.close()
+                self.show_task_errors()
 
     def show_ccp4_not_found(self):
-        print 'show ccp4 errors'
         msg = QtGui.QMessageBox()
         msg.setIcon(QtGui.QMessageBox.Information)
         q_settings = QtCore.QSettings()
@@ -253,7 +257,7 @@ class CCPEMMainWindow(QtGui.QMainWindow):
         if self.active_project_path is not None:
             self.database_path = os.path.join(
                 self.ccpem_projects.get_active_project().path,
-                '.ccpemDB.sqlite')
+                sqlite_project_database.CCPEMDatabase.ccpem_db_filename)
             self.database = sqlite_project_database.CCPEMDatabase(
                 database_path=self.database_path)
         else:
@@ -352,18 +356,17 @@ class CCPEMMainWindow(QtGui.QMainWindow):
             self.set_task_button_disabled(self.button_run_flexem)
 
         # LocScale
-        if self.args.alpha():
-            self.button_run_loc_scale = QtGui.QPushButton(
-                'LocScale',
-                self)
-            self.task_buttons_layout.addWidget(self.button_run_loc_scale)
-            if self.tasks.loc_scale is not None:
-                self.button_run_loc_scale.setToolTip(
-                    self.tasks.flex_em.task.task_info.short_description)
-                self.button_run_loc_scale.clicked.connect(
-                    self.handle_run_loc_scale)
-            else:
-                self.set_task_button_disabled(self.button_run_loc_scale)
+        self.button_run_loc_scale = QtGui.QPushButton(
+            'LocScale',
+            self)
+        self.task_buttons_layout.addWidget(self.button_run_loc_scale)
+        if self.tasks.loc_scale is not None:
+            self.button_run_loc_scale.setToolTip(
+                self.tasks.loc_scale.task.task_info.short_description)
+            self.button_run_loc_scale.clicked.connect(
+                self.handle_run_loc_scale)
+        else:
+            self.set_task_button_disabled(self.button_run_loc_scale)
 
         # Molrep
         self.button_run_molrep = QtGui.QPushButton(
@@ -428,18 +431,6 @@ class CCPEMMainWindow(QtGui.QMainWindow):
         else:
             self.set_task_button_disabled(self.button_run_nautilus)
 
-        # Ribfind
-        self.button_run_ribfind = QtGui.QPushButton(
-            'Ribfind',
-            self)
-        self.task_buttons_layout.addWidget(self.button_run_ribfind)
-        if self.tasks.ribfind is not None:
-            self.button_run_ribfind.setToolTip(
-                self.tasks.ribfind.task.task_info.short_description)
-            self.button_run_ribfind.clicked.connect(self.handle_run_ribfind)
-        else:
-            self.set_task_button_disabled(self.button_run_ribfind)
-
         #
         self.button_run_prosmart = QtGui.QPushButton(
             'ProSMART',
@@ -464,6 +455,18 @@ class CCPEMMainWindow(QtGui.QMainWindow):
         else:
             self.set_task_button_disabled(self.button_run_refmac5)
 
+        # Ribfind
+        self.button_run_ribfind = QtGui.QPushButton(
+            'Ribfind',
+            self)
+        self.task_buttons_layout.addWidget(self.button_run_ribfind)
+        if self.tasks.ribfind is not None:
+            self.button_run_ribfind.setToolTip(
+                self.tasks.ribfind.task.task_info.short_description)
+            self.button_run_ribfind.clicked.connect(self.handle_run_ribfind)
+        else:
+            self.set_task_button_disabled(self.button_run_ribfind)
+
         # Shake
         self.button_run_shake = QtGui.QPushButton(
             'Shake',
@@ -489,7 +492,7 @@ class CCPEMMainWindow(QtGui.QMainWindow):
                 self.handle_run_tempy_difference_map)
         else:
             self.set_task_button_disabled(self.button_run_tempy_difference_map)
-
+        '''
         # TEMPy:SCCC
         self.button_run_tempy_sccc = QtGui.QPushButton(
             'TEMPy: SCCC',
@@ -502,10 +505,10 @@ class CCPEMMainWindow(QtGui.QMainWindow):
                 self.handle_run_tempy_sccc)
         else:
             self.set_task_button_disabled(self.button_run_tempy_sccc)
-
+        '''
         # TEMPy: SMOC
         self.button_run_tempy_smoc = QtGui.QPushButton(
-            'TEMPy: SMOC',
+            'TEMPy: Local score',
             self)
         self.task_buttons_layout.addWidget(self.button_run_tempy_smoc)
         if self.tasks.tempy_smoc is not None:
@@ -515,6 +518,19 @@ class CCPEMMainWindow(QtGui.QMainWindow):
                 self.handle_run_tempy_smoc)
         else:
             self.set_task_button_disabled(self.button_run_tempy_smoc)
+        
+        # TEMPy: GlobScore
+        self.button_run_tempy_scores = QtGui.QPushButton(
+            'TEMPy: Scores',
+            self)
+        self.task_buttons_layout.addWidget(self.button_run_tempy_scores)
+        if self.tasks.tempy_scores is not None:
+            self.button_run_tempy_scores.setToolTip(
+                self.tasks.tempy_scores.task.task_info.short_description)
+            self.button_run_tempy_scores.clicked.connect(
+                self.handle_run_tempy_scores)
+        else:
+            self.set_task_button_disabled(self.button_run_tempy_scores)
 
         ### Utilities
         # Separator
@@ -884,6 +900,23 @@ See below for list of missing tasks.
             parent=self,
             task=task)
         window.show()
+    
+    def handle_run_tempy_scores(self):
+        if self.test_mode:
+            args_json = os.path.join(
+                self.tasks.tempy_scores.test_data,
+                'unittest_args.json')
+        else:
+            args_json = None
+        task = self.tasks.tempy_scores.task(
+            parent=self,
+            args_json=args_json,
+            database_path=self.database_path)
+        window = self.tasks.tempy_scores.window(
+            parent=self,
+            task=task)
+        window.show()
+
 
     def handle_run_tempy_sccc(self):
         if self.test_mode:
@@ -925,12 +958,31 @@ See below for list of missing tasks.
         window = mrc_edit_window.CCPEMMrcEditWindow(parent=self)
         window.show()
 
+    def echo_main_window(self):
+        '''
+        For testing
+        '''
+        print ('CCP-EM Main Window')
+
+
 class MainWindowProjectView(database_widget.CCPEMProjectTableView):
     def __init__(self, main_window):
         super(MainWindowProjectView, self).__init__(parent=main_window)
         self.main_window = main_window
         self.tasks = main_window.tasks
 
+    def clone_custom(self, args_json):
+        task_class = self.tasks.get_task_class(program=self.program)
+        window_class = self.tasks.get_window_class(program=self.program)
+        task = task_class(
+            parent=self,
+            args_json=args_json,
+            database_path=self.main_window.database_path)
+        window = window_class(
+            parent=self,
+            task=task)
+        window.show()
+
     def on_click_custom(self, index, path):
         program_index = index.sibling(index.row(),
                                       self.model.fieldIndex('program'))
