@@ -15,7 +15,7 @@ from PyQt4 import QtGui, QtCore, QtWebKit
 from ccpem_core.tasks.refmac import refmac_task
 from ccpem_gui.utils import window_utils
 from ccpem_core.ccpem_utils import ccpem_file_types
-from ccpem_gui.project_database import sqlite_project_database
+from ccpem_gui.utils import command_line_launch
 
 
 class RefmacDataset(object):
@@ -652,6 +652,13 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
         refinement_options_frame.add_extension_widget(self.weight_input)
         self.set_weight_auto()
 
+        # -> Weight auto
+        self.symmetry_auto_input = window_utils.CheckArgInput(
+            parent=self,
+            arg_name='symmetry_auto',
+            args=self.args)
+        refinement_options_frame.add_extension_widget(self.symmetry_auto_input)
+
         # -> Map sharpen
         map_sharpen_input = window_utils.NumberArgInput(
             parent=self,
@@ -675,7 +682,7 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
             args=self.args)
         refinement_options_frame.add_extension_widget(hydrogens_input)
 
-        # -> Input cig
+        # -> Input ligand cif library
         lib_input = window_utils.FileArgInput(
             parent=self,
             arg_name='lib_in',
@@ -809,6 +816,13 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
         self.validation_frame.add_extension_widget(self.half_map_2_input)
 
         # -> Reference map
+        # Validation frame
+        self.validation_advanced_frame = window_utils.CCPEMExtensionFrame(
+            button_name='Advanced options',
+            button_tooltip='Show advanced validation options')
+        self.validation_frame.add_extension_frame(
+            self.validation_advanced_frame)
+
         self.reference_map_input = window_utils.FileArgInput(
             parent=self,
             arg_name='reference_map',
@@ -822,7 +836,8 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
                 if isinstance(input_map, list):
                     input_map = input_map[0]
                 self.reference_map_input.set_arg_value(input_map)
-        self.validation_frame.add_extension_widget(self.reference_map_input)
+        self.validation_advanced_frame.add_extension_widget(
+            self.reference_map_input)
 
         # Keyword frame
         keyword_frame = window_utils.CCPEMExtensionFrame(
@@ -976,14 +991,6 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
         '''
         Over ride from baseclass to allow validation of multiple datasets
         '''
-        if self.database_path is not None:
-            db = sqlite_project_database.CCPEMDatabase(
-                database_path=self.database_path)
-            job_id = db.insert_new_job(program=self.task.task_info.name,
-                                       job_location='None')
-        else:
-            job_id=None
-
         if self.check_input():
             if self.args.dc_mode():
                 # Valdited multiple datasets
@@ -1004,7 +1011,7 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
                       external_weight_scales_arg=self.args.external_weight_scales,
                       external_weight_gmwts_arg=self.args.external_weight_gmwts)
 
-            self.run_detached_process(job_id=job_id)
+            self.run_detached_process()
 
 
     def set_on_job_running_custom(self):
@@ -1057,11 +1064,11 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
 
 def main():
     '''
-    Launch stand alone window.
+    Launch standalone task runner.
     '''
-    window_utils.standalone_window_launch(
-        task=refmac_task.Refmac,
-        window=Refmac5Window)
+    command_line_launch.ccpem_task_launch(
+        task_class=refmac_task.Refmac,
+        window_class=Refmac5Window)
 
 if __name__ == '__main__':
     main()
