@@ -7,17 +7,13 @@
 #     CCP-EM Secretary, RAL Laboratory, Harwell, OX11 0FA, UK.
 #
 
-import sys
 import os
 import types
 import textwrap
-import json
-from collections import OrderedDict
 from PyQt4 import QtGui, QtCore
 from ccpem_gui.icons import icon_utils
 from ccpem_gui.utils import ccpem_widgets, gui_process
 from ccpem_core.mrc_map_io_clipper import read_mrc_header
-from ccpem_core import ccpem_utils
 from ccpem_core import settings
 from ccpem_core import process_manager
 from ccpem_gui import icons
@@ -25,6 +21,8 @@ from ccpem_gui.utils import ccpem_launcher_widget
 from ccpem_core.ccpem_utils import ccpem_file_types
 from ccpem_gui.utils import ccpem_pipeline_viewer
 from ccpem_gui.project_database import sqlite_project_database
+from ccpem_core.process_manager import job_register
+
 
 class CCPEMArgsWidget(QtGui.QWidget):
     def __init__(self, parent=None):
@@ -41,68 +39,6 @@ class CCPEMArgsWidget(QtGui.QWidget):
         self.setLayout(layout)
 
 
-def standalone_window_launch(task,
-                             window,
-                             args_json=None,
-                             pipeline = None):
-    '''
-    Launch task standalone task GUI.
-    '''
-    # Print header
-    message = 'CCP-EM | ' + task.task_info.name
-    ccpem_utils.print_header(message=message)
-    message = 'CCP-EM standalone window task'
-    ccpem_utils.print_sub_header(message=message)
-    print '  Usage:'
-    info = OrderedDict([
-        ('ccpem-<name> <args.json>', 'Set inputs from JSON file'),
-        ('ccpem-<name> <job directory>', 'Load previous job')])
-    for key in info.keys():
-        print '    {0: <34} {1}'.format(key, info[key])
-
-    # Read args or pipeline from previous job
-    for arg in sys.argv:
-        if args_json is None:
-            if arg[-5:] == '.json':
-                try:
-                    json.load(open(arg, 'r'))
-                    args_json = arg
-                except ValueError:
-                    args_json = None
-                    message = 'Can not read {0}'.format(arg)
-                    ccpem_utils.print_warning(message=message)
-
-        find_pipeline = os.path.join(arg, 'task.ccpem')
-        find_pipeline = os.path.abspath(find_pipeline)
-
-        if os.path.exists(find_pipeline):
-            pipeline = process_manager.CCPEMPipeline(pipeline=None)
-            pipeline.import_json(jsonfile=find_pipeline)
-
-    # Set job location
-    job_location = os.path.join(os.getcwd(),
-                                task.task_info.name + '_1')
-    # Run task
-    run_task = task(args_json=args_json,
-                    job_location=job_location,
-                    pipeline=pipeline)
-
-    # Launch GUI
-    app = QtGui.QApplication(sys.argv)
-    if sys.platform == 'linux' or sys.platform == 'linux2':
-        style = 'plastique'
-        app.setStyle(style)
-        app.setStyleSheet('''QToolTip {background-color: black;
-                                       color: white; 
-                                       border: black solid 1px
-                                       }''')
-    app.setWindowIcon(QtGui.QIcon(icons.icon_utils.get_ccpem_icon()))
-    CCPEMStandAloneWindow(
-        task=run_task,
-        window=window)
-    sys.exit(app.exec_())
-
-
 class CCPEMStandAloneWindow(QtGui.QWidget):
     '''
     Dummy window for launching thread safe stand alone windows.
@@ -110,9 +46,7 @@ class CCPEMStandAloneWindow(QtGui.QWidget):
     def __init__(self,
                  task,
                  window,
-                 parent=None,
-                 database_path=None,
-                 pipeline=None):
+                 parent=None):
         super(CCPEMStandAloneWindow, self).__init__(parent)
         self.task = task
         self.window = window(
@@ -165,15 +99,15 @@ class CCPEMStandAloneWindow(QtGui.QWidget):
         toolbar = QtGui.QToolBar()
         toolbar.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
         #
-        new_icon = os.path.join(icon_utils.get_theme_icons_path(),
-                                'actions/window-new.png')
+        clone_icon = os.path.join(icon_utils.get_icons_path(),
+                                 'ccpem_icons/clone_32x32.png')
         toolbar.addAction(
-            QtGui.QIcon(new_icon),
-            'New',
+            QtGui.QIcon(clone_icon),
+            'Clone',
             self.new_task_window)
         #
-        folder_icon = os.path.join(icon_utils.get_theme_icons_path(),
-                                   'status/folder-open.png')
+        folder_icon = os.path.join(icon_utils.get_icons_path(),
+                                   'font_awesome/folder_open_32x32.png')
         toolbar.addAction(
             QtGui.QIcon(folder_icon),
             'Folder',
@@ -234,9 +168,6 @@ class CCPEMTaskWindow(QtGui.QMainWindow):
         self.launcher = ccpem_launcher_widget.CCPEMLauncher(
             parent=self)
         self.set_args()
-        # Add stretch to end of args widget
-        self.args_widget.args_layout.addStretch(2)
-
         self.set_pipeline_ui()
         self.set_launcher_ui()
         if self.pipeline is not None:
@@ -256,6 +187,7 @@ class CCPEMTaskWindow(QtGui.QMainWindow):
         raise NotImplementedError('Subclasses should implement this')
 
     def create_child(self):
+        self.set_all_inputs()
         child_args = self.args.deep_copy()
         child_task = self.task.__class__(args=child_args,
                                          database_path=self.database_path)
@@ -386,73 +318,65 @@ class CCPEMTaskWindow(QtGui.QMainWindow):
         #
         self.status = 'ready'
         #
-        run_icon = os.path.join(icon_utils.get_theme_icons_path(),
-                                'actions/system-run.png')
+        run_icon = os.path.join(icon_utils.get_icons_path(),
+                                'ccpem_icons/run_32x32.png')
         self.tb_run_button = self.tool_bar.addAction(
             QtGui.QIcon(run_icon),
             'Run',
             self.handle_toolbar_run)
         self.tb_run_button.setToolTip('Run task process')
         #
-        new_icon = os.path.join(icon_utils.get_theme_icons_path(),
-                                'actions/window-new.png')
-        self.tb_new_button = self.tool_bar.addAction(
-            QtGui.QIcon(new_icon),
-            'New',
+        clone_icon = os.path.join(icon_utils.get_icons_path(),
+                                'ccpem_icons/clone_32x32.png')
+        self.tb_clone_button = self.tool_bar.addAction(
+            QtGui.QIcon(clone_icon),
+            'Clone',
             self.create_child)
-        self.tb_new_button.setToolTip('Clone into new job')
-
-        #
-        open_icon = os.path.join(icon_utils.get_theme_icons_path(),
-                                 'actions/document-open-recent.png')
-        self.tb_load_button = self.tool_bar.addAction(
-            QtGui.QIcon(open_icon),
-            'Load',
-            self.handle_toolbar_load)
-        self.tb_load_button.setToolTip('Load previous job')
+        self.tb_clone_button.setToolTip(
+            'Clone current settings into a new job')
         #
         if settings.which(program='coot') is not None:
             coot_icon = os.path.join(icon_utils.get_other_icons_path(),
-                                     'coot_icon.png')
+                                     'coot_32x32.png')
             self.tb_coot_button = self.tool_bar.addAction(
                 QtGui.QIcon(coot_icon),
                 'Coot',
                 self.run_coot)
         #
-        if settings.which(program='ccp4mg') is not None:
-            ccp4mg_icon = os.path.join(icon_utils.get_other_icons_path(),
-                                       'ccp4mg_icon.png')
-            self.tb_ccp4mg_button = self.tool_bar.addAction(
-                QtGui.QIcon(ccp4mg_icon),
-                'CCP4mg',
-                self.run_ccp4mg)
-        #
         if settings.which(program='chimera') is not None:
             chimera_icon = os.path.join(icon_utils.get_other_icons_path(),
-                                        'chimera_icon_no_iccp.png')
+                                        'chimera_32x32.png')
             self.tb_chimera_button = self.tool_bar.addAction(
                 QtGui.QIcon(chimera_icon),
                 'Chimera',
                 self.run_chimera)
         #
-        terminal_icon = os.path.join(icon_utils.get_theme_icons_path(),
-                                     'apps/terminal.png')
+        if settings.which(program='ccp4mg') is not None:
+            ccp4mg_icon = os.path.join(icon_utils.get_other_icons_path(),
+                                       'ccp4mg_32x32.png')
+            self.tb_ccp4mg_button = self.tool_bar.addAction(
+                QtGui.QIcon(ccp4mg_icon),
+                'CCP4mg',
+                self.run_ccp4mg)
+        #
+        terminal_icon = os.path.join(icon_utils.get_icons_path(),
+                                     'font_awesome/terminal_32x32.png')
         self.tb_terminal_button = self.tool_bar.addAction(
             QtGui.QIcon(terminal_icon),
             'Terminal',
             self.run_terminal)
         self.tb_terminal_button.setEnabled(False)
         #
-        folder_icon = os.path.join(icon_utils.get_theme_icons_path(),
-                                   'status/folder-open.png')
+        folder_icon = os.path.join(icon_utils.get_icons_path(),
+                                   'font_awesome/folder_open_32x32.png')
         self.tb_browser_button = self.tool_bar.addAction(
             QtGui.QIcon(folder_icon),
             'Output',
             self.run_file_browser)
         self.tb_browser_button.setEnabled(False)
         #
-        info_icon = os.path.join(icon_utils.get_theme_icons_path(),
-                                 'status/dialog-question.png')
+        info_icon = os.path.join(icon_utils.get_icons_path(),
+                                'ccpem_icons/info_32x32.png')
         self.tb_info_button = self.tool_bar.addAction(
             QtGui.QIcon(info_icon),
             'Info',
@@ -464,8 +388,8 @@ class CCPEMTaskWindow(QtGui.QMainWindow):
                              QtGui.QSizePolicy.Expanding)
         self.tool_bar.addWidget(spacer)
         #
-        stop_icon = os.path.join(icon_utils.get_theme_icons_path(),
-                                 'actions/process-stop.png')
+        stop_icon = os.path.join(icon_utils.get_icons_path(),
+                                  'font_awesome/stop_32x32.png')
         self.tb_stop_button = self.tool_bar.addAction(
             QtGui.QIcon(stop_icon),
             'Kill',
@@ -601,20 +525,22 @@ class CCPEMTaskWindow(QtGui.QMainWindow):
         '''
         Run task.
         '''
+        self.set_all_inputs()
         if self.check_input():
-            if self.database_path is not None:
-                db = sqlite_project_database.CCPEMDatabase(
-                    database_path=self.database_path)
-                job_id = db.insert_new_job(program=self.task.task_info.name,
-                                           job_location='None')
-            else:
-                job_id=None
-            self.run_detached_process(job_id=job_id)
+            self.run_detached_process()
+
+    def set_all_inputs(self):
+        '''
+        Set all input values.  Done explicity when a task is run or cloned
+        as editFinished signal can be by-passed in some circumstances.
+        '''
+        for child in self.findChildren(CCPEMArgBaseWidget):
+            child.on_edit_finished()
 
     def check_input(self):
         '''
         Check required inputs are set, display warning message if not.
-        '''  
+        '''
         base_classes = self.findChildren(CCPEMArgBaseWidget)
         ready = True
         warnings = []
@@ -632,15 +558,25 @@ class CCPEMTaskWindow(QtGui.QMainWindow):
                                       text)
         return ready
 
-    def run_detached_process(self, job_id=None):
+    def run_detached_process(self):
         '''
         Launch detached job.
         '''
+        # Register job
+        path = self.task.job_location
         db_inject = None
         if self.database_path is not None:
+            path = os.path.dirname(self.database_path)
             db_inject = sqlite_project_database.CCPEMInjector(
                 database_path=self.database_path)
-        self.task.run_task(job_id=job_id,
+
+        job_id, job_location = job_register.job_register(
+            path=path,
+            db_inject=db_inject,
+            task_name=self.task.task_info.name)
+        #
+        self.task.run_task(job_location=job_location,
+                           job_id=job_id,
                            db_inject=db_inject)
         self.pipeline = self.task.pipeline
         self.set_on_job_running()
@@ -722,7 +658,6 @@ class CCPEMTaskWindow(QtGui.QMainWindow):
                 self.job_status_timer.start(500)
                 self.tb_stop_button.setEnabled(True)
                 self.tb_run_button.setEnabled(False)
-                self.tb_load_button.setEnabled(False)
                 self.tb_browser_button.setEnabled(True)
                 self.tb_terminal_button.setEnabled(True)
                 self.disable_args_widgets()
@@ -748,7 +683,6 @@ class CCPEMTaskWindow(QtGui.QMainWindow):
         self.status_widget.set_finished()
         self.tb_run_button.setEnabled(False)
         self.disable_args_widgets()
-        self.tb_load_button.setEnabled(True)
         self.tb_browser_button.setEnabled(True)
         self.tb_terminal_button.setEnabled(True)
         self.tb_stop_button.setEnabled(False)
@@ -776,7 +710,6 @@ class CCPEMTaskWindow(QtGui.QMainWindow):
         '''
         self.status_widget.set_failed()
         self.tb_run_button.setEnabled(False)
-        self.tb_load_button.setEnabled(True)
         self.tb_browser_button.setEnabled(True)
         self.tb_stop_button.setEnabled(False)
         self.job_status_timer.stop()
@@ -873,6 +806,72 @@ class CCPEMExtensionFrame(QtGui.QVBoxLayout):
     def disable(self):
         self.button.setDisabled(True)
 
+class CCPEMRadioButton(QtGui.QWidget):
+    def __init__(self,
+                 button_name,
+                 button_tooltip,
+                 button_dependant=False):
+        super(CCPEMExtensionFrame, self).__init__()
+        self.button = QtGui.QRadioButton(button_name)
+        self.button_dependant = button_dependant
+        self.button.clicked.connect(self.button_clicked)
+        self.button.setToolTip(button_tooltip)
+        self.button.setAutoExclusive(False)
+        self.addWidget(self.button)
+        self.frame = QtGui.QFrame()
+        self.frame.setFrameStyle(
+            QtGui.QFrame.StyledPanel | QtGui.QFrame.Sunken)
+        self.frame_layout = QtGui.QVBoxLayout()
+        self.frame.setLayout(self.frame_layout)
+        self.addWidget(self.frame)
+        self.button_clicked()
+        self.active = True
+
+    def hide(self):
+        self.frame.hide()
+        self.button.hide()
+
+    def show(self):
+        self.frame.show()
+        self.button.show()
+        self.button.setChecked(True)
+
+
+    def add_extension_widget(self, widget):
+        '''
+        Convenience function to add widget to extension frame layout.
+        '''
+        self.frame_layout.addWidget(widget)
+        if self.button_dependant:
+            if hasattr(widget, 'set_active'):
+                widget.set_active(self.button.isChecked())
+
+    def add_extension_frame(self, layout):
+        '''
+        Convenience function to add layout to extension frame layout.
+        '''
+        self.frame_layout.addLayout(layout)
+
+    def button_clicked(self):
+        #
+        if self.button.isChecked():
+            self.frame.show()
+            active = True
+        else:
+            self.frame.hide()
+            active = False
+        if self.button_dependant:
+            # Set children active state
+            # N.B. can't use findChildren with layouts so use get widget item
+            children = self.frame_layout.count()
+            for i in xrange(children):
+                child = self.frame_layout.itemAt(i).widget()
+                if hasattr(child, 'set_active'):
+                    child.set_active(active)
+
+    def disable(self):
+        self.button.setDisabled(True)
+
 
 class CCPEMArgBaseWidget(QtGui.QWidget):
     '''
@@ -913,9 +912,6 @@ class CCPEMArgBaseWidget(QtGui.QWidget):
             if arg.nargs == '*':
                 self.multiple_values = True
 
-        if required:
-            self.tooltip_text += ' | Required'
-
         # If tooltip greater than max length insert returns
         max_len = 60
         if len(self.tooltip_text) > max_len:
@@ -947,8 +943,7 @@ class CCPEMArgBaseWidget(QtGui.QWidget):
         self.value_line = None
 
         # Set required shading
-        if self.required and self.action.value is None:
-            self.set_shading(shade=True)
+        self.set_required(required=required)
 
     def on_edit_finished(self):
         '''
@@ -977,6 +972,13 @@ class CCPEMArgBaseWidget(QtGui.QWidget):
         else:
             self.set_shading(shade=False)
 
+    def set_required(self, required):
+        self.required = required
+        if self.required and self.action.value is None:
+            self.set_shading(shade=True)
+        else:
+            self.set_shading(shade=False)
+
     def set_shading(self, shade=True):
         '''
         Shade text QLineEdit red to display warning.
@@ -1123,8 +1125,6 @@ class ListArgInput(CCPEMArgBaseWidget):
         Set argument value on edit finished.
         '''
         value = self.value_line.text()
-        if value == '':
-            value = '0'
         self.set_arg_value(value=value)
 
     def set_arg_value(self, value):
@@ -1133,8 +1133,8 @@ class ListArgInput(CCPEMArgBaseWidget):
         to none or if path does not exist.
         '''
         # Set arg value
-        if value in ['', 'None']:
-            self.action.value = None
+        if value in ['', None]:
+            self.action.value = []
         else:
             if type(value) is list:
                 self.action.value = self.action.type(value)
@@ -1147,8 +1147,8 @@ class ListArgInput(CCPEMArgBaseWidget):
                     try:
                         v = self.element_type(v)
                         value_list.append(v)
-                    except:
-                        TypeError
+                    except (TypeError, ValueError):
+                        pass
                 self.action.value = self.action.type(value_list)
         # Set display value
         if hasattr(self.value_line, 'setText'):
@@ -1157,10 +1157,10 @@ class ListArgInput(CCPEMArgBaseWidget):
                 try:
                     v = str(v)
                     values += (v + ', ')
-                except:
-                    TypeError
+                except (TypeError, ValueError):
+                    pass
             self.value_line.setText(values)
-        if self.action.value is None:
+        if len(self.action.value) == 0:
             if self.required:
                 self.set_shading(shade=True)
             else:
@@ -1266,7 +1266,7 @@ class NumberArgInput(CCPEMArgBaseWidget):
                  arg_name,
                  args,
                  decimals=2,
-                 step=0.1,
+                 step=None,
                  minimum=0,
                  maximum=999,
                  label=None,
@@ -1292,9 +1292,14 @@ class NumberArgInput(CCPEMArgBaseWidget):
         if self.action.type == float:
             self.value_line = QtGui.QDoubleSpinBox()
             self.value_line.setDecimals(decimals)
+            if step is None:
+                step = 0.1
             self.value_line.setSingleStep(step)
         else:
+            if step is None:
+                step = 1
             self.value_line = QtGui.QSpinBox()
+            self.value_line.setSingleStep(step)
         if self.set_none:
             if self.action() is None:
                 self.value_line.setValue(0)
@@ -1306,7 +1311,7 @@ class NumberArgInput(CCPEMArgBaseWidget):
         self.grid_layout.addWidget(self.value_line, 0, 1)
 
         # Signal value change
-        self.value_line.valueChanged.connect(self.on_edit_finished)
+        self.value_line.editingFinished.connect(self.on_edit_finished)
 
         # Set initial value
         self.set_arg_value(value=set_value)
@@ -1315,14 +1320,14 @@ class NumberArgInput(CCPEMArgBaseWidget):
         '''
         Set argument value.  Apply warning shade to if arg is required and set
         to none or if path does not exist.
-        '''        
+        '''
         if self.set_none and (
                 value is None or
                     value == self.value_line.specialValueText()):
             value = self.value_line.minimum()
         else:
             self.action.value = self.action.type(value)
-            
+
         self.value_line.setValue(self.action.type(value))
         if self.action.value is None:
             if self.required:
@@ -1413,6 +1418,9 @@ class CheckArgInput(CCPEMArgBaseWidget):
             if hasattr(dependant, 'required'):
                 dependant.required = True
 
+    def on_edit_finished(self):
+        pass
+
 
 class ChoiceArgInput(CCPEMArgBaseWidget):
     '''
@@ -1454,6 +1462,9 @@ class ChoiceArgInput(CCPEMArgBaseWidget):
         if init_value in self.choices:
             self.set_arg_value(value=self.choices.index(init_value))
 
+    def on_edit_finished(self):
+        pass
+
     def set_arg_value(self, value):
         '''
         Set argument value.  Apply warning shade to if arg is required and set
@@ -1472,7 +1483,7 @@ class ChoiceArgInput(CCPEMArgBaseWidget):
         self.value_line.setEnabled(False)
 
 
-class KeywordArgInput(FileArgInput):
+class KeywordArgInput(CCPEMArgBaseWidget):
     def __init__(self,
                  parent,
                  arg_name,
@@ -1493,65 +1504,27 @@ class KeywordArgInput(FileArgInput):
             required=required)
         self.file_types = ccpem_file_types.text_ext
         #
-        self.grid_layout.addWidget(self.keyword_edit, 1, 0, 1, 3)
+        self.grid_layout.addWidget(self.keyword_edit, 1, 0)
+        self.set_arg_value(value=self.action.value)
 
     def text_changed(self):
         self.action.value = str(self.keyword_edit.toPlainText())
 
     def set_arg_value(self, value):
-        '''
-        If file
-        '''
-        if value is not None:
-            if os.path.exists(value):
-                f = open(value, 'r')
-                self.action.value = f.read()
-                f.close()
-                self.keyword_edit.clear()
-            else:
-                self.action.value = value
-            self.keyword_edit.insertPlainText(str(self.action.value))
-
-#         if value in ['', None, 'None']:
-#             self.action.value = None
-#         else:
-#             self.action.value = self.action.type(value)
-#         self.value_line.setText(str(value))
-#         #
-#         if self.action.value is not None:
-#             if not os.path.exists(self.action.value):
-#                 self.set_shading(shade=True)
-#             else:
-#                 self.set_shading(shade=False)
-#         elif self.active and self.required:
-#                 self.set_shading(shade=True)
-#         else:
-#             self.set_shading(shade=False)
-
-    def select_button_clicked(self):
-        '''
-        Select file using file dialog.
-        '''
-        filename = self.open_file_dialog()
-        if filename is not None:
-            filename = str(filename)
-            if ccpem_file_types.check_text_file(filename):
-                self.value_line.setText(str(filename))
-                self.keywords_str = open(filename, 'r').read()
-                self.keyword_edit.setPlainText(self.keywords_str)
-                self.action.value = str(self.keyword_edit.toPlainText())
-            else:
-                text = 'Warning: {0} not text file'.format(filename)
-                QtGui.QMessageBox.warning(self,
-                                          'Error',
-                                          text)
+        if value in ['', None, 'None']:
+            self.action.value = None
+        else:
+            self.keyword_edit.setPlainText(str(value))
+        self.action.value = self.action.type(value)
 
     def disable(self):
         '''
         Disable widget functions.  For use when processes is running.
         '''
         self.keyword_edit.setReadOnly(True)
-        self.select_button.setEnabled(False)
+
+    def on_edit_finished(self):
+        pass
 
 
 class SequenceArgInput(FileArgInput):
@@ -1603,9 +1576,15 @@ class SequenceArgInput(FileArgInput):
             self.value_line.hide()
             self.select_button.hide()
             value = str(self.keyword_edit.toPlainText())
-        
+
         self.set_arg_value(value=value)
 
+    def on_edit_finished(self):
+        if self.text_button.isChecked():
+            self.text_changed()
+        else:
+            super(SequenceArgInput, self).on_edit_finished()
+
     def text_changed(self):
         value = str(self.keyword_edit.toPlainText())
         self.set_arg_value(value=value)
@@ -1728,7 +1707,7 @@ class MRCMapHeaderInfo(QtGui.QWidget):
                 self.map_data = read_mrc_header.MRCMapHeaderData(self.filename)
                 # checks both the extension and the header of the target mapfile
                 if self.map_data.is_map_file:
-                    # XXX 
+                    # XXX
                     map_params = {'dim_x': self.map_data.mx_my_mz[0],
                                   'dim_y': self.map_data.mx_my_mz[1],
                                   'dim_z': self.map_data.mx_my_mz[2],
@@ -1789,9 +1768,6 @@ def relaunch_task_window(task_class,
     window.show()
 
 
-
-
-
 def main():
     '''
     For testing.
