@@ -42,9 +42,6 @@
 !=******************************************************************************
 !
 !
-!ShapeMv1.1, amr 8/5/15 handle smaller sobj and mask
-!v1.2 change cx,cy,cz to absolute centre in the std unit cell
-
 
 !ShapeMv1.0
 
@@ -94,7 +91,6 @@
 	character*3 num
 	logical t,f
 	real x,y,z,maskth
-	integer lx,ly,lz,bnx,bny,bnz
 	integer nm8,numatoms
 	real*8 summap,sumcccs,sumnumccc,stdccc
 	real cx,cy,cz
@@ -104,12 +100,11 @@
 	integer sloop,ssteps
 	real comx,comy,comz,r
 	integer i,j,k
-        character*2 box
 	
 	t=.true.
 	f=.false.
 
-        print*, 'ShapeM, V1.2'
+        print*, 'ShapeM, V1.0'
         print*, '============'
 
 
@@ -139,13 +134,6 @@
 30      format (I3)
 
         pdbfile = 'com'//num(runcode)//'.pdb'       
-
-33	print*,'Origin of rotation at center-of-mass of search object, or the box center.  Type> C or B'
-	read*,box
-	if ((box.ne.'C') .and. (box .ne.'B') .and. (box.ne.'c') .and. (box .ne.'c')) goto 33	
-	endif
-        
-
 ! pdb file com used to record origin of rotations.
  
 
@@ -166,11 +154,7 @@
 	nxm1=nx-1
         nym1=ny-1
         nzm1=nz-1
-
-        bnx=nx
-        bny=ny
-        bnz=nz
-
+        
         nxp1=nx+1
         nxp2=nx+2
         
@@ -183,26 +167,8 @@
         allocate (AA(0:nxp1,0:nym1,0:nzm1))
 	   
         CALL READMRCMAP(1,filename,map,nx,ny,nz,T,F,T,err) !read, is open, dont close, add 2 bytes
-
-
-        CALL IMOPEN(2,sobjfilename,'RO')
-        CALL IRDHDR(2,NXYZ,MXYZ,MODE,DMIN,DMAX,DMEAN)
-	lx=nx
-	ly=ny
-	lz=nz
-
-
-        CALL READMRCMAP2(2,sobjfilename,sobj,bnx,bny,bnz,lx,ly,lz,F,T,T,err) !read, is open,  close, add 2 bytes 
-
-
-
-        CALL IMOPEN(2,maskfilename,'RO')
-        CALL IRDHDR(2,NXYZ,MXYZ,MODE,DMIN,DMAX,DMEAN)
-        CALL READMRCMAP2(2,maskfilename,mask,bnx,bny,bnz,lx,ly,lz,F,T,T,err) !read, is open,  close, add 2 bytes  
-	
-
-        CALL IRDHDR(1,NXYZ,MXYZ,MODE,DMIN,DMAX,DMEAN)
-
+        CALL READMRCMAP(2,sobjfilename,sobj,nx,ny,nz,F,T,T,err) !read, not open,  close, add 2 bytes         
+        CALL READMRCMAP(3,maskfilename,mask,nx,ny,nz,F,T,T,err) !read, not open,  close, add 2 bytes  
 
 !make mask binary
 
@@ -251,13 +217,9 @@
 	do I=1,nx
 	 do j=1,ny
 	   do k=1,nz
- 		comx = comx + commap(i,j,k) * (float(i))
- 		comy = comy + commap(i,j,k) * (float(j))
- 		comz = comz + commap(i,j,k) * (float(k))
-!v1.2
-
-
-
+ 		comx = comx + commap(i,j,k) * (float(i)-cx)
+ 		comy = comy + commap(i,j,k) * (float(j)-cy)
+ 		comz = comz + commap(i,j,k) * (float(k)-cz)
 	   enddo
 	  enddo
 	enddo
@@ -265,11 +227,6 @@
         comy=comy/sum(commap)
         comz=comz/sum(commap)
 
-	if ((box.eq.'B') .or. (box .eq.'b') then
-		comx=cx
-		comy=cy
-		comz=cz
-	endif
 
 !save the com to pdbfile
 
@@ -569,58 +526,6 @@
      	
 	END SUBROUTINE READMRCMAP
 	
-
-	SUBROUTINE READMRCMAP2(stream,filename,map,X,Y,Z,lx,ly,lz,open,close,add2,err)
- 
-        Use mrc_image
-
-         INTEGER  X,Y,Z,err
-         INTEGER  stream, IX,IY,IZ,xm1
-         real, DIMENSION (0:X+1,0:Y-1,0:Z-1) :: map  
-         INTEGER S(3),S1
-         logical add2,open,close
-         character*80 filename
-            
-          if(.not. open) then
-          	       CALL IMOPEN(stream,filename,'RO')
-       		       CALL IRDHDR(stream,NXYZ,MXYZ,MODE,DMIN,DMAX,DMEAN)
-	  endif
-            
-         
-      
-      
-!     read in file 
-
-      DO 1350 IZ = 0,nz-1
-          DO 1350 IY = 0,ny-1
-            CALL IRDLIN(stream,ALINE,*1998)
-            DO 1300 IX = 0,nx-1       
-       !     print*,ix
-                map(ix,iy,iz) = ALINE(IX+1)
-1300         CONTINUE  
-	if(add2) then  
-     		       map(X+0,iy,iz)=0
-      		       map(X+1,iy,iz)=0
-        endif
-        
-!           print*,ix,iy,iz
-
-
-
-
-
-1350   CONTINUE
-
-	if (close) then
-		CALL IMCLOSE(stream)
-		print*,'closed ',stream
-	endif
-
-      return
-1998   STOP 'Error on file read.'
-     	
-	END SUBROUTINE READMRCMAP2
-	
 	
        
       SUBROUTINE WRITEMRCMAP(stream,map,x,y,z,sampling,err)
