@@ -3,9 +3,10 @@ import os, sys
 import math
 import time
 import argparse
-import pyrvapi_ext as API
 import subprocess as SP
 
+import pyrvapi_ext as API
+
 class logWriter(object):
 
   def __init__(self, logfile, nrecords):
@@ -63,7 +64,8 @@ def main():
   dir_data = os.path.join(ccp4, 'examples', 'toxd')
   pdb_inp = os.path.join(dir_data, 'toxd.pdb')
   mtz_inp = os.path.join(dir_data, 'toxd_mapcoefs.mtz')
-  testdir = os.path.abspath('testdir_jsrview')
+  demodir = os.path.dirname(os.path.abspath(__file__))
+  testdir = os.path.join(demodir, 'testdir_jsrview')
   logfile = os.path.join(testdir, 'output.log')
   xmlfile = os.path.join(testdir, 'output.xml')
 
@@ -194,9 +196,10 @@ def main():
   time.sleep(delay1)
   log.dump_fraction(0.05)
 
-  structure = API.pyrvapi_pdb_mtz('Structure and electron density', sec2, 2, 0, 1, 1, 1)
-  structure.set_paths(pdb_inp, mtz_inp)
+  structure = API.pyrvapi_data('Structure and electron density', sec2, 2, 0, 1, 1, 1)
+  structure.append(pdb_inp, 'xyz')
   structure.draw()
+  structure.append(mtz_inp, 'hkl:map')
 
   API.flush()
 
