@@ -3,39 +3,35 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
  'AR': 'ar',
  'ARFLAGS': 'rc',
- 'ASDLGEN': '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/checkout/Python-2.7.11/Parser/asdl_c.py',
- 'ASDLGEN_FILES': '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/checkout/Python-2.7.11/Parser/asdl.py /home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/checkout/Python-2.7.11/Parser/asdl_c.py',
- 'AST_ASDL': '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/checkout/Python-2.7.11/Parser/Python.asdl',
- 'AST_C': 'Python/Python-ast.c',
- 'AST_C_DIR': 'Python',
- 'AST_H': 'Include/Python-ast.h',
- 'AST_H_DIR': 'Include',
  'ATHEOS_THREADS': 0,
  'BASECFLAGS': '-fno-strict-aliasing',
  'BASEMODLIBS': '',
  'BEOS_THREADS': 0,
- 'BINDIR': '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/libexec',
- 'BINLIBDEST': '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/lib/python2.7',
+ 'BINDIR': '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/libexec',
+ 'BINLIBDEST': '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/lib/python2.7',
  'BLDLIBRARY': '-L. -lpython2.7',
- 'BLDSHARED': 'gcc -pthread -shared -L/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/lib -s -Wl,--hash-style=both -Wl,--build-id=sha1',
+ 'BLDSHARED': 'gcc -pthread -shared -L/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/lib -s -Wl,--hash-style=both -Wl,--build-id=sha1',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
  'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-fno-strict-aliasing -O3 -fno-strict-aliasing -pipe -mtune=core2 -DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes',
+ 'CFLAGS': '-fno-strict-aliasing -O2 -fno-strict-aliasing -pipe -march=core2 -mtune=generic -DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes',
  'CFLAGSFORSHARED': '-fPIC',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
- 'CONFIG_ARGS': "'--prefix' '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install' '--disable-Werror' '--bindir=/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/libexec' '--enable-silent-rules' '--enable-shared' '--disable-static' 'CC=gcc' 'CFLAGS=-O3 -fno-strict-aliasing -pipe -mtune=core2' 'LDFLAGS=-L/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/lib -s -Wl,--hash-style=both -Wl,--build-id=sha1' 'PKG_CONFIG_PATH=/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/lib/pkgconfig:/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/share/pkgconfig:/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/installlib/pkgconfig'",
- 'CONFINCLUDEDIR': '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/include',
- 'CONFINCLUDEPY': '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/include/python2.7',
+ 'CONFIG_ARGS': "'--prefix' '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install' '--disable-Werror' '--bindir=/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/libexec' '--enable-unicode=ucs4' '--enable-silent-rules' '--enable-shared' '--disable-static' 'CC=gcc' 'CFLAGS=-O2 -fno-strict-aliasing -pipe -march=core2 -mtune=generic' 'LDFLAGS=-L/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/lib -s -Wl,--hash-style=both -Wl,--build-id=sha1' 'PKG_CONFIG_PATH=/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/lib/pkgconfig:/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/share/pkgconfig:/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/installlib/pkgconfig'",
+ 'CONFINCLUDEDIR': '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/include',
+ 'CONFINCLUDEPY': '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/include/python2.7',
  'COREPYTHONPATH': ':plat-linux2:lib-tk:lib-old',
- 'CPPFLAGS': '-I. -IInclude -I/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/checkout/Python-2.7.11/Include',
+ 'COVERAGE_INFO': '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/builddir/Python-2.7.15.tgz/coverage.info',
+ 'COVERAGE_REPORT': '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/builddir/Python-2.7.15.tgz/lcov-report',
+ 'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov report"',
+ 'CPPFLAGS': '-I. -IInclude -I/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/checkout/Python-2.7.15/Include',
  'CXX': 'g++ -pthread',
  'C_THREADS': 0,
- 'DESTDIRS': '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install /home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/lib /home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/lib/python2.7 /home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/lib/python2.7/lib-dynload',
- 'DESTLIB': '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/lib/python2.7',
+ 'DESTDIRS': '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install /home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/lib /home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/lib/python2.7 /home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/lib/python2.7/lib-dynload',
+ 'DESTLIB': '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/lib/python2.7',
  'DESTPATH': '',
- 'DESTSHARED': '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/lib/python2.7/lib-dynload',
+ 'DESTSHARED': '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/lib/python2.7/lib-dynload',
  'DIRMODE': 755,
  'DIST': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in Include Lib Misc Demo Ext-dummy',
  'DISTDIRS': 'Include Lib Misc Demo Ext-dummy',
@@ -58,11 +54,11 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'FLOCK_NEEDS_LIBBSD': 0,
  'GETPGRP_HAVE_ARG': 0,
  'GETTIMEOFDAY_NO_TZ': 0,
+ 'GITBRANCH': '',
+ 'GITTAG': '',
+ 'GITVERSION': '',
  'GLHACK': '-Dclear=__GLclear',
  'GNULD': 'yes',
- 'GRAMMAR_C': 'Python/graminit.c',
- 'GRAMMAR_H': 'Include/graminit.h',
- 'GRAMMAR_INPUT': '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/checkout/Python-2.7.11/Grammar/Grammar',
  'HAVE_ACOSH': 1,
  'HAVE_ADDRINFO': 1,
  'HAVE_ALARM': 1,
@@ -91,12 +87,21 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_CONFSTR': 1,
  'HAVE_CONIO_H': 0,
  'HAVE_COPYSIGN': 1,
+ 'HAVE_CRYPT_H': 1,
  'HAVE_CTERMID': 1,
  'HAVE_CTERMID_R': 0,
+ 'HAVE_CURSES_FILTER': 1,
  'HAVE_CURSES_H': 1,
+ 'HAVE_CURSES_HAS_KEY': 1,
+ 'HAVE_CURSES_IMMEDOK': 1,
+ 'HAVE_CURSES_IS_PAD': 0,
  'HAVE_CURSES_IS_TERM_RESIZED': 1,
  'HAVE_CURSES_RESIZETERM': 1,
  'HAVE_CURSES_RESIZE_TERM': 1,
+ 'HAVE_CURSES_SYNCOK': 1,
+ 'HAVE_CURSES_TYPEAHEAD': 1,
+ 'HAVE_CURSES_USE_ENV': 1,
+ 'HAVE_CURSES_WCHGAT': 1,
  'HAVE_DECL_ISFINITE': 1,
  'HAVE_DECL_ISINF': 1,
  'HAVE_DECL_ISNAN': 1,
@@ -228,7 +233,6 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_PTHREAD_SIGMASK': 1,
  'HAVE_PTY_H': 1,
  'HAVE_PUTENV': 1,
- 'HAVE_RAND_EGD': 1,
  'HAVE_READLINK': 1,
  'HAVE_REALPATH': 1,
  'HAVE_RL_CALLBACK': 1,
@@ -238,6 +242,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_RL_COMPLETION_MATCHES': 1,
  'HAVE_RL_COMPLETION_SUPPRESS_APPEND': 1,
  'HAVE_RL_PRE_INPUT_HOOK': 1,
+ 'HAVE_RL_RESIZE_TERMINAL': 1,
  'HAVE_ROUND': 1,
  'HAVE_SELECT': 1,
  'HAVE_SEM_GETVALUE': 1,
@@ -288,7 +293,6 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_STRUCT_STAT_ST_GEN': 0,
  'HAVE_STRUCT_STAT_ST_RDEV': 1,
  'HAVE_STRUCT_TM_TM_ZONE': 1,
- 'HAVE_ST_BLOCKS': 1,
  'HAVE_SYMLINK': 1,
  'HAVE_SYSCONF': 1,
  'HAVE_SYSEXITS_H': 1,
@@ -305,11 +309,13 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_SYS_NDIR_H': 0,
  'HAVE_SYS_PARAM_H': 1,
  'HAVE_SYS_POLL_H': 1,
+ 'HAVE_SYS_RANDOM_H': 0,
  'HAVE_SYS_RESOURCE_H': 1,
  'HAVE_SYS_SELECT_H': 1,
  'HAVE_SYS_SOCKET_H': 1,
  'HAVE_SYS_STATVFS_H': 1,
  'HAVE_SYS_STAT_H': 1,
+ 'HAVE_SYS_SYSMACROS_H': 1,
  'HAVE_SYS_TERMIO_H': 0,
  'HAVE_SYS_TIMES_H': 1,
  'HAVE_SYS_TIME_H': 1,
@@ -351,14 +357,11 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_WORKING_TZSET': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
- 'HGBRANCH': 'hg id -b /home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/checkout/Python-2.7.11',
- 'HGTAG': 'hg id -t /home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/checkout/Python-2.7.11',
- 'HGVERSION': 'hg id -i /home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/checkout/Python-2.7.11',
- 'HOST_GNU_TYPE': 'x86_64-unknown-linux-gnu',
+ 'HOST_GNU_TYPE': 'x86_64-pc-linux-gnu',
  'HURD_C_THREADS': 0,
- 'INCLDIRSTOMAKE': '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/include /home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/include /home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/include/python2.7 /home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/include/python2.7',
- 'INCLUDEDIR': '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/include',
- 'INCLUDEPY': '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/include/python2.7',
+ 'INCLDIRSTOMAKE': '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/include /home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/include /home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/include/python2.7 /home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/include/python2.7',
+ 'INCLUDEDIR': '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/include',
+ 'INCLUDEPY': '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/include/python2.7',
  'INSTALL': '/usr/bin/install -c',
  'INSTALL_DATA': '/usr/bin/install -c -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c',
@@ -366,21 +369,21 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'INSTALL_SHARED': '/usr/bin/install -c -m 555',
  'INSTSONAME': 'libpython2.7.so.1.0',
  'LDCXXSHARED': 'g++ -pthread -shared',
- 'LDFLAGS': '-L/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/lib -s -Wl,--hash-style=both -Wl,--build-id=sha1',
+ 'LDFLAGS': '-L/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/lib -s -Wl,--hash-style=both -Wl,--build-id=sha1',
  'LDLAST': '',
  'LDLIBRARY': 'libpython2.7.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'gcc -pthread -shared -L/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/lib -s -Wl,--hash-style=both -Wl,--build-id=sha1',
+ 'LDSHARED': 'gcc -pthread -shared -L/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/lib -s -Wl,--hash-style=both -Wl,--build-id=sha1',
  'LIBC': '',
- 'LIBDEST': '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/lib/python2.7',
- 'LIBDIR': '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/lib',
+ 'LIBDEST': '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/lib/python2.7',
+ 'LIBDIR': '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/lib',
  'LIBFFI_INCLUDEDIR': '',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
- 'LIBP': '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/lib/python2.7',
- 'LIBPC': '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/lib/pkgconfig',
- 'LIBPL': '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/lib/python2.7/config',
+ 'LIBP': '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/lib/python2.7',
+ 'LIBPC': '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/lib/pkgconfig',
+ 'LIBPL': '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/lib/python2.7/config',
  'LIBRARY': 'libpython2.7.a',
  'LIBRARY_OBJS': '\\',
  'LIBS': '-lpthread -ldl  -lutil',
@@ -396,14 +399,14 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'MACHDEPPATH': ':plat-linux2',
  'MACHDEPS': 'plat-linux2',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/lib/python2.7',
+ 'MACHDESTLIB': '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/lib/python2.7',
  'MACH_C_THREADS': 0,
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': 'gcc -pthread',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
- 'MAKESETUP': '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/checkout/Python-2.7.11/Modules/makesetup',
- 'MANDIR': '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/share/man',
+ 'MAKESETUP': '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/checkout/Python-2.7.15/Modules/makesetup',
+ 'MANDIR': '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/share/man',
  'MEMTESTOPTS': '-l -x test_subprocess test_io test_lib2to3 \\ -x test_dl test___all__ test_fork1 \\',
  'MKDIR_P': '/bin/mkdir -p',
  'MODLIBS': '',
@@ -413,9 +416,6 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'MVWDELCH_IS_EXPRESSION': 1,
  'OBJECT_OBJS': '\\',
  'OLDPATH': ':lib-old',
- 'OPCODETARGETGEN': '\\',
- 'OPCODETARGETGEN_FILES': '\\',
- 'OPCODETARGETS_H': '\\',
  'OPT': '-DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
@@ -438,7 +438,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'PLATMACPATH': ':plat-mac:plat-mac/lib-scriptpackages',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
- 'PROFILE_TASK': '-m test.regrtest --pgo',
+ 'PROFILE_TASK': '-m test.regrtest --pgo -x test_asyncore test_gdb test_multiprocessing test_subprocess',
  'PSRCS': '\\',
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PURIFY': '',
@@ -450,22 +450,23 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'PYTHONFRAMEWORKPREFIX': '',
  'PYTHONPATH': ':plat-linux2:lib-tk:lib-old',
  'PYTHON_FOR_BUILD': './python -E',
+ 'PYTHON_FOR_REGEN': 'python2.7',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
- 'PY_CFLAGS': '-fno-strict-aliasing -O3 -fno-strict-aliasing -pipe -mtune=core2 -DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes -I. -IInclude -I/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/checkout/Python-2.7.11/Include -fPIC -DPy_BUILD_CORE',
+ 'PY_CFLAGS': '-fno-strict-aliasing -O2 -fno-strict-aliasing -pipe -march=core2 -mtune=generic -DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes -I. -IInclude -I/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/checkout/Python-2.7.15/Include -fPIC -DPy_BUILD_CORE',
  'PY_FORMAT_LONG_LONG': '"ll"',
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_UNICODE_TYPE': 'unsigned short',
+ 'PY_UNICODE_TYPE': 0,
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
- 'Py_UNICODE_SIZE': 2,
+ 'Py_UNICODE_SIZE': 4,
  'Py_USING_UNICODE': 1,
  'QUICKTESTOPTS': '-l -x test_subprocess test_io test_lib2to3 \\',
  'RANLIB': 'ranlib',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/builddir/Python-2.7.11.tgz:/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/lib:/opt/rh/devtoolset-2/root/usr/lib64:/opt/rh/devtoolset-2/root/usr/lib',
- 'SCRIPTDIR': '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/lib',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/builddir/Python-2.7.15.tgz:/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/lib:/opt/software/cuda/8.0/lib64:/opt/rh/devtoolset-3/root/usr/lib64:/opt/rh/devtoolset-3/root/usr/lib',
+ 'SCRIPTDIR': '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '',
  'SHELL': '/bin/sh',
@@ -492,14 +493,13 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
  'SO': '.so',
- 'SRCDIRS': 'Parser Grammar Objects Python Modules Mac',
- 'SRC_GDB_HOOKS': '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/checkout/Python-2.7.11/Tools/gdb/libpython.py',
+ 'SRCDIRS': 'Parser Objects Python Modules',
+ 'SRC_GDB_HOOKS': '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/checkout/Python-2.7.15/Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
  'STRINGLIB_HEADERS': '\\',
  'SUBDIRS': '',
  'SUBDIRSTOO': 'Include Lib Misc Demo',
- 'SVNVERSION': 'svnversion /home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/checkout/Python-2.7.11',
  'SYSLIBS': '-lm',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TANH_PRESERVES_ZERO_SIGN': 1,
@@ -507,8 +507,8 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'TCLTK_LIBS': '',
  'TESTOPTS': '-l',
  'TESTPATH': '',
- 'TESTPROG': '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/checkout/Python-2.7.11/Lib/test/regrtest.py',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/builddir/Python-2.7.11.tgz:/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/lib:/opt/rh/devtoolset-2/root/usr/lib64:/opt/rh/devtoolset-2/root/usr/lib ./python -Wd -3 -E -tt',
+ 'TESTPROG': '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/checkout/Python-2.7.15/Lib/test/regrtest.py',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/builddir/Python-2.7.15.tgz:/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/lib:/opt/software/cuda/8.0/lib64:/opt/rh/devtoolset-3/root/usr/lib64:/opt/rh/devtoolset-3/root/usr/lib ./python -Wd -3 -E -tt',
  'TESTPYTHONOPTS': '',
  'THREADOBJ': 'Python/thread.o',
  'TIME_WITH_SYS_TIME': 1,
@@ -520,7 +520,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'USE_TOOLBOX_OBJECT_GLUE': 0,
  'VA_LIST_IS_ARRAY': 1,
  'VERSION': '2.7',
- 'VPATH': '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/checkout/Python-2.7.11',
+ 'VPATH': '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/checkout/Python-2.7.15',
  'WANT_SIGFPE_HANDLER': 0,
  'WANT_WCTYPE_FUNCTIONS': 0,
  'WINDOW_HAS_FLAGS': 1,
@@ -534,11 +534,11 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/builddir/Python-2.7.11.tgz',
- 'abs_srcdir': '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/checkout/Python-2.7.11',
- 'build': 'x86_64-unknown-linux-gnu',
- 'datarootdir': '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/share',
- 'exec_prefix': '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install',
- 'host': 'x86_64-unknown-linux-gnu',
- 'prefix': '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install',
- 'srcdir': '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/checkout/Python-2.7.11'}
+ 'abs_builddir': '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/builddir/Python-2.7.15.tgz',
+ 'abs_srcdir': '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/checkout/Python-2.7.15',
+ 'build': 'x86_64-pc-linux-gnu',
+ 'datarootdir': '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/share',
+ 'exec_prefix': '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install',
+ 'host': 'x86_64-pc-linux-gnu',
+ 'prefix': '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install',
+ 'srcdir': '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/checkout/Python-2.7.15'}
