@@ -27,20 +27,20 @@ import re
 # These are installation specific values created when SIP was configured.
 _pkg_config = {
     'arch':               '',
-    'default_bin_dir':    '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/devbin/../bin',
-    'default_mod_dir':    '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/lib/python2.7/site-packages',
-    'default_sip_dir':    '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/share/sip',
+    'default_bin_dir':    '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/devbin/../bin',
+    'default_mod_dir':    '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/lib/python2.7/site-packages',
+    'default_sip_dir':    '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/share/sip',
     'deployment_target':  '',
     'platform':           'linux-g++',
-    'py_conf_inc_dir':    '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/include/python2.7',
-    'py_inc_dir':         '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/include/python2.7',
-    'py_lib_dir':         '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/lib/python2.7/config',
-    'py_version':         0x02070b,
+    'py_conf_inc_dir':    '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/include/python2.7',
+    'py_inc_dir':         '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/include/python2.7',
+    'py_lib_dir':         '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/lib/python2.7/config',
+    'py_version':         0x02070f,
     'qt_framework':       0,
-    'sip_bin':            '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/devbin/sip',
-    'sip_config_args':    '--bindir=/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/devbin --destdir=/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/lib/python2.7/site-packages --incdir=/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/include --sipdir=/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/share/sip LFLAGS+=-L/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/lib -s -Wl,--hash-style=both -Wl,--build-id=sha1',
-    'sip_inc_dir':        '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/include',
-    'sip_mod_dir':        '/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/lib/python2.7/site-packages',
+    'sip_bin':            '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/devbin/sip',
+    'sip_config_args':    '--bindir=/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/devbin --destdir=/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/lib/python2.7/site-packages --incdir=/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/include --sipdir=/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/share/sip LFLAGS+=-L/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/lib -s -Wl,--hash-style=both -Wl,--build-id=sha1',
+    'sip_inc_dir':        '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/include',
+    'sip_mod_dir':        '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/lib/python2.7/site-packages',
     'sip_version':        0x041009,
     'sip_version_str':    '4.16.9',
     'universal':          ''
@@ -99,7 +99,7 @@ _default_macros = {
     'INCDIR':                   '',
     'INCDIR_OPENGL':            '/usr/X11R6/include',
     'INCDIR_X11':               '/usr/X11R6/include',
-    'LFLAGS':                   '-L/home/jenkins/workspace/ccpem/sl6_devtoolset/devtools/install/lib -s -Wl,--hash-style=both -Wl,--build-id=sha1',
+    'LFLAGS':                   '-L/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/lib -s -Wl,--hash-style=both -Wl,--build-id=sha1',
     'LFLAGS_CONSOLE':           '',
     'LFLAGS_CONSOLE_DLL':       '',
     'LFLAGS_DEBUG':             '',
