@@ -1,10 +1,10 @@
 
 /*
- *  =================================================================
+ *  ==========================================================================
  *
- *    06.12.17   <--  Date of Last Modification.
+ *    15.10.18   <--  Date of Last Modification.
  *                   ~~~~~~~~~~~~~~~~~~~~~~~~~~~~
- *  -----------------------------------------------------------------
+ *  --------------------------------------------------------------------------
  *
  *  **** Module  :  js-client/gui/gui.tree.js
  *       ~~~~~~~~~
@@ -13,26 +13,84 @@
  *  **** Content :  Generic tree class
  *       ~~~~~~~~~
  *
- *  (C) E. Krissinel, A. Lebedev 2016-2017
+ *  (C) E. Krissinel, A. Lebedev 2016-2018
  *
- *  =================================================================
+ *  ==========================================================================
+ *
+ *
+ *    Requires: 	jquery.js
+ *                style(.min).css  // from jstree distro
+ *                jstree(.min).js
+ *                gui.widgets.js
+ *                js-common/dtypes/common.dtypes.box.js
+ *
+ *   URL:  https://www.jstree.com
+ *
+ *  --------------------------------------------------------------------------
+ *
+ *   class TreeNodeCustomIcon  {
+ *      constructor TreeNodeCustomIcon ( uri,width,height,state );
+ *   }
+ *
+ *  --------------------------------------------------------------------------
+ *
+ *   class TreeNode : Widget  {
+ *
+ *      constructor TreeNode ( text,icon_uri,treeNodeCustomIcon );
+ *
+ *      function setSelected();
+ *      function copy ( node );
+ *      function setCustomIconVisible ( visible_bool );
+ *
+ *   }
+ *
+ *  --------------------------------------------------------------------------
+ *
+ *   class Tree {
+ *
+ *      constructor Tree ( rootName );
+ *
+ *      function addRootNode      ( text,icon_uri,treeNodeCustomIcon );
+ *      function addNode          ( parent_node,text,icon_uri,treeNodeCustomIcon );
+ *      function insertNode       ( parent_node,text,icon_uri,treeNodeCustomIcon );
+ *      function getNodePosition  ( node );
+ *      function moveNodeUp       ( node );
+ *      function getChildNodes    ( node );
+ *      function setNodes         ( nodes );
+ *      function getNumberOfNodes ();
+ *      function selectNode       ( node,single_bool );
+ *      function selectSingle     ( node );
+ *      function deselectNode     ( node );
+ *      function deselectNodeById ( nodeId );
+ *      function selectSingleById ( nodeId );
+ *      function forceSingleSelection();
+ *      function setText          ( node,text );
+ *      function setIcon          ( node,icon_uri );
+ *      function setStyle         ( treeNode,style_str,propagate_int );
+ *      function confirmCustomIconsVisibility();
+ *      function deleteNode       ( node );
+ *      function deleteBranch     ( node );
+ *      function createTree       ( onReady_func   ,onContextMenu_func,
+ *                                  onDblClick_func,onSelect_func );
+ *      function refresh              ();
+ *      function calcSelectedNodeId   ();
+ *      function getSelectedNodeId    ();
+ *      function calcSelectedNode     ();
+ *      function getSelectedNode      ();
+ *      function addNodeToSelected    ( text,icon_uri,treeNodeCustomIcon );
+ *      function insertNodeAfterSelected ( text,icon_uri,treeNodeCustomIcon );
+ *      function addSiblingToSelected ( text,icon_uri,treeNodeCustomIcon );
+ *      function deleteSelectedNode   ();
+ *      function moveSelectedNodeUp   ();
+ *      function deleteSelectedNodes  ();
+ *
+ *   }
  *
  */
 
-/*
 
-  Requires: 	jquery.js
-  	          style(.min).css  // from jstree distro
-  	          jstree(.min).js
-              gui.widgets.js
-
-  URL:  https://www.jstree.com
-
-*/
-
-
-// -------------------------------------------------------------------------
-// TreeNode class
+// ===========================================================================
+// TreeNodeCustomIcon class
 
 function TreeNodeCustomIcon ( uri,width,height,state )  {
   this.customIcon = uri;
@@ -42,6 +100,9 @@ function TreeNodeCustomIcon ( uri,width,height,state )  {
 }
 
 
+// ===========================================================================
+// TreeNode class
+
 function TreeNode ( text,icon_uri,treeNodeCustomIcon )  {
   this.id             = 'treenode_' + padDigits(__id_cnt++,5);  // node element id (unstable)
   this.parentId       = null;           // parent node element id (unstable)
@@ -106,14 +167,15 @@ var ci_element = document.getElementById(this.id + '_pbar');
 }
 */
 
-// -------------------------------------------------------------------------
+// ===========================================================================
 // Tree class
 
 function Tree ( rootName )  {
 
   Widget.call ( this,'div' );
 
-  this.addWidget ( new Label(rootName) );
+  this.root_label = new Label ( rootName );
+  this.addWidget ( this.root_label );
   this.root       = new Widget('div');
   this.addWidget ( this.root );
   this.root_nodes = [];       //
@@ -166,7 +228,10 @@ var node = new TreeNode ( text,icon_uri,treeNodeCustomIcon );
   this.root_nodes.push ( node );
   this.node_map[node.id] = node;
   if (this.created)  {
+    var snode = $.extend ( {},node );
     $(this.root.element).jstree(true).create_node('#',node,'last',false,false);
+    // jstree modifies node stricture, therefore extend it with custom fields
+    node = $.extend ( node,snode );
     this.selectSingle ( node );  // force selection of new nodes if tree is displayed
     this.confirmCustomIconsVisibility();
   }
@@ -180,9 +245,12 @@ var node = new TreeNode ( text,icon_uri,treeNodeCustomIcon );
   parent_node.children.push ( node );
   this.node_map[node.id] = node;
   if (this.created)  {
+    var snode = $.extend ( {},node );
     $(this.root.element).jstree(true).create_node('#'+parent_node.id,node,'last',false,false);
-    node.data     = treeNodeCustomIcon;  // this gets lost, duplicate, jstree bug
-    node.children = [];                  // this gets lost, duplicate, jstree bug
+    // jstree modifies node stricture, therefore extend it with custom fields
+    node = $.extend ( node,snode );
+    //node.data     = treeNodeCustomIcon;  // this gets lost, duplicate, jstree bug
+    //node.children = [];                  // this gets lost, duplicate, jstree bug
     this.selectSingle ( node );  // force selection of new nodes if tree is displayed
     this.confirmCustomIconsVisibility();
   }
@@ -206,8 +274,8 @@ Tree.prototype.insertNode = function ( parent_node,text,icon_uri,treeNodeCustomI
       $(this.root.element).jstree(true).move_node(children,node,'last',false,false);
       node.data = treeNodeCustomIcon;  // this gets lost, duplicate, jstree bug
       node.children = children;
-      this.selectSingle ( node );  // force selection of new nodes if tree is displayed
       $(this.root.element).jstree().refresh();
+      this.selectSingle ( node );  // force selection of new nodes if tree is displayed
       this.confirmCustomIconsVisibility();
     } else
       node.children = children;
@@ -216,6 +284,136 @@ Tree.prototype.insertNode = function ( parent_node,text,icon_uri,treeNodeCustomI
 }
 
 
+Tree.prototype.getChildNodes = function ( node )  {
+  if (node)  return node.children;
+       else  return [];
+}
+
+
+Tree.prototype.getNodePosition = function ( node )  {
+var parent_node = null;
+var parentId    = null;
+var clen        = 0;
+var pos         = -2;
+
+  if (node.parentId)  {
+    parent_node = this.node_map[node.parentId];
+    if (parent_node)  {
+      parentId = parent_node.parentId;
+
+      var parent_children = parent_node.children;
+      clen = parent_children.length;
+
+      // find sibling position of given node
+      pos = -1;
+      for (var i=0;(i<clen) && (pos<0);i++)
+        if (parent_children[i].id==node.id)
+          pos = i;
+
+    }
+  }
+
+  return [pos,parent_node,parentId,clen];
+
+}
+
+
+Tree.prototype.moveNodeUp = function ( node )  {
+
+  if (node.parentId)  {
+
+    var parent_node = this.node_map[node.parentId];
+
+    if (parent_node.parentId)  {  // do not move above the root
+
+      var parent_children = parent_node.children;
+
+      // find sibling position of given node
+      var pos = -1;
+      for (var i=0;(i<parent_children.length) && (pos<0);i++)
+        if (parent_children[i].id==node.id)
+          pos = i;
+
+      if (pos>0)  {
+        // given node is not leading sibling; push it up with all its children
+
+        if (this.created)
+          $(this.root.element).jstree(true).move_node(node,parent_node,pos-1,false,false);
+
+        // reflect changes in internal list of children
+        var snode = parent_children[pos-1];
+        parent_children[pos-1] = parent_children[pos];
+        parent_children[pos]   = snode;
+
+      } else if (parent_children.length>1) {
+        // given node is the leading sibling; convert other siblings to its children
+
+        var siblings = [];
+        for (var i=0;i<parent_children.length;i++)
+          if (parent_children[i].id!=node.id)
+            siblings.push ( parent_children[i] );
+
+        if (this.created)
+          $(this.root.element).jstree(true).move_node(siblings,node,'last',false,false);
+
+        // reflect changes in internal list of children
+        for (var i=0;i<siblings.length;i++)
+          siblings[i].parentId = node.id;
+        node.children = node.children.concat ( siblings );
+        parent_node.children = [node];
+
+      } else  {
+        // given node is the only child of its parent; make it parent's parent
+
+        var grandpa_node      = this.node_map[parent_node.parentId];
+        var node_children     = node.children;
+        var grandpa_children  = grandpa_node.children;
+        node.children         = [];
+        parent_node.children  = [];
+        grandpa_node.children = [];
+
+        // node moves up and becomes child of grand_parent_node
+        // parent_node becomes child of node and receives all its children
+        if (this.created)  {
+          $(this.root.element).jstree(true).move_node(parent_node,node,'last',false,false);
+          $(this.root.element).jstree(true).move_node(node,grandpa_node,'last',false,false);
+          $(this.root.element).jstree(true).move_node(node_children,parent_node,'last',false,false);
+        }
+
+        for (var i=0;i<parent_children.length;i++)
+          if (parent_children[i].id!=node.id)
+            parent_node.children.push ( parent_children[i] );
+        parent_node.children = parent_node.children.concat ( node_children );
+        for (var i=0;i<parent_node.children.length;i++)
+          parent_node.children[i].parentId = parent_node.id;
+
+        node.children = [parent_node];
+        parent_node.parentId = node.id;
+
+        // grand parent node loses parent_node as a child but gets node instead
+        for (var i=0;i<grandpa_children.length;i++)
+          if (grandpa_children[i].id!=parent_node.id)
+            grandpa_node.children.push ( grandpa_children[i] );
+        grandpa_node.children.push ( node );
+        node.parentId = grandpa_node.id;
+
+      }
+
+      // force selection and refresh the tree
+      if (this.created)  {
+        this.selectSingle ( node );  // force selection of the node if tree is displayed
+        $(this.root.element).jstree().refresh();
+        this.confirmCustomIconsVisibility();
+      }
+
+    }
+
+  }
+
+}
+
+
+/*  ------  working version 09.03.2018
 Tree.prototype.moveNodeUp = function ( node )  {
 
   if (node.parentId)  {
@@ -267,6 +465,7 @@ Tree.prototype.moveNodeUp = function ( node )  {
     }
   }
 }
+*/
 
 
 /*
@@ -364,9 +563,30 @@ sel = sel[0];
 sel = ref_treeview.create_node(sel, "childNode", "last", CreateNode,true);
 */
 
-Tree.prototype.selectSingle = function ( node )  {
+
+Tree.prototype.selectNode = function ( node,single_bool )  {
 // This function will select given node and deselect all others
 
+  if (single_bool && (this.selected_node_id in this.node_map))
+    this.node_map[this.selected_node_id].state.selected = false;
+
+  if (this.created)  {
+    if (single_bool)
+      $(this.root.element).jstree('deselect_all');
+    $(this.root.element).jstree(true).select_node('#'+node.id);
+  }
+
+  node.state.selected   = true;
+  this.selected_node_id = node.id;
+
+}
+
+
+Tree.prototype.selectSingle = function ( node )  {
+// This function will select given node and deselect all others
+  this.selectNode ( node,true );
+
+/*
   if (this.selected_node_id in this.node_map)
     this.node_map[this.selected_node_id].state.selected = false;
 
@@ -377,10 +597,28 @@ Tree.prototype.selectSingle = function ( node )  {
 
   node.state.selected   = true;
   this.selected_node_id = node.id;
+*/
 
 }
 
 
+Tree.prototype.selectMultiple = function ( node )  {
+// This function will select given node
+  this.selectNode ( node,false );
+}
+
+
+Tree.prototype.deselectNode = function ( node )  {
+  if (this.created)
+    $(this.root.element).jstree(true).deselect_node('#'+node.id);
+}
+
+Tree.prototype.deselectNodeById = function ( nodeId )  {
+  if (this.created)
+    $(this.root.element).jstree(true).deselect_node('#'+nodeId);
+}
+
+
 Tree.prototype.selectSingleById = function ( nodeId )  {
   if (nodeId in this.node_map)
     this.selectSingle ( this.node_map[nodeId] );
@@ -403,6 +641,13 @@ Tree.prototype.setText = function ( node,text )  {
     $(this.root.element).jstree(true).rename_node('#'+node.id,text);
 }
 
+
+Tree.prototype.setIcon = function ( node,icon_uri )  {
+  node.icon = icon_uri;
+  if (this.created)
+    $(this.root.element).jstree(true).set_icon('#'+node.id,icon_uri);
+}
+
 /*
 Tree.prototype.setTextColor = function ( node,color_str )  {
   if (this.created)
@@ -455,6 +700,21 @@ Tree.prototype.confirmCustomIconsVisibility = function()  {
 }
 
 
+Tree.prototype.clear = function()  {
+  // clears all the tree including root nodes; works only on created trees
+
+  for (var i=0;i<this.root_nodes.length;i++)  {
+    this.deleteChildren ( this.root_nodes[i] );
+    $(this.root.element).jstree(true).delete_node('#'+this.root_nodes[i].id);
+  }
+
+  this.root_nodes = [];       //
+  this.node_map   = {};       // node_map[nodeId] == TreeNode
+  this.selected_node_id = '';
+
+}
+
+
 Tree.prototype.deleteNode = function ( node )  {
 // does not delete root node(s)
 
@@ -467,6 +727,143 @@ Tree.prototype.deleteNode = function ( node )  {
   if (!(node.id in this.node_map))
     return;
 
+  if (!(node.parentId in this.node_map))
+    return;
+
+  //  remove node from children list of its parent
+  var pnode     = this.node_map[node.parentId];  // parent node
+  var pchildren = [];  // new paren children
+  var selNo     = -1;
+  for (var i=0;i<pnode.children.length;i++)  {
+    if (pnode.children[i].id==node.id) {
+      selNo = i;
+      // copy node's children to parent children list
+      for (var j=0;j<node.children.length;j++)  {
+        pchildren.push ( node.children[j] );
+        node.children[j].parentId = pnode.id;
+      }
+    } else  {
+      pchildren.push ( pnode.children[i] );
+    }
+  }
+  pnode.children = pchildren;
+
+  // remove node from general tree index
+  this.node_map[node.id] = null;
+  var node_map = {};  // new node map
+  for (var key in this.node_map)
+    if (this.node_map[key])
+      node_map[key] = this.node_map[key];
+  this.node_map = node_map;
+
+  if (this.created)  {
+    $(this.root.element).jstree(true).move_node(node.children,pnode,'last',false,false);
+    // remove node from tree
+    $(this.root.element).jstree(true).delete_node('#'+node.id);
+    this.confirmCustomIconsVisibility();
+    if (pnode.children.length>0)
+          this.selectSingle ( pnode.children[0] );
+    else  this.selectSingle ( pnode );
+  }
+
+  /*
+  // find sibling position of given node
+  var pos = -1;
+  for (var i=0;(i<parent_children.length) && (pos<0);i++)
+    if (parent_children[i].id==node.id)
+      pos = i;
+
+  if (pos>0)  {
+    // given node is not leading sibling; push it up with all its children
+
+    if (this.created)
+      $(this.root.element).jstree(true).move_node(node,parent_node,pos-1,false,false);
+
+    // reflect changes in internal list of children
+    var snode = parent_children[pos-1];
+    parent_children[pos-1] = parent_children[pos];
+    parent_children[pos]   = snode;
+
+  } else if (parent_children.length>1) {
+    // given node is the leading sibling; convert other siblings to its children
+
+    var siblings = [];
+    for (var i=0;i<parent_children.length;i++)
+      if (parent_children[i].id!=node.id)
+        siblings.push ( parent_children[i] );
+
+    if (this.created)
+      $(this.root.element).jstree(true).move_node(siblings,node,'last',false,false);
+
+    // reflect changes in internal list of children
+    for (var i=0;i<siblings.length;i++)
+      siblings[i].parentId = node.id;
+    node.children = node.children.concat ( siblings );
+    parent_node.children = [node];
+
+  } else  {
+    // given node is the only child of its parent; make it parent's parent
+
+    var grandpa_node      = this.node_map[parent_node.parentId];
+    var node_children     = node.children;
+    var grandpa_children  = grandpa_node.children;
+    node.children         = [];
+    parent_node.children  = [];
+    grandpa_node.children = [];
+
+    // node moves up and becomes child of grand_parent_node
+    // parent_node becomes child of node and receives all its children
+    if (this.created)  {
+      $(this.root.element).jstree(true).move_node(parent_node,node,'last',false,false);
+      $(this.root.element).jstree(true).move_node(node,grandpa_node,'last',false,false);
+      $(this.root.element).jstree(true).move_node(node_children,parent_node,'last',false,false);
+    }
+
+    for (var i=0;i<parent_children.length;i++)
+      if (parent_children[i].id!=node.id)
+        parent_node.children.push ( parent_children[i] );
+    parent_node.children = parent_node.children.concat ( node_children );
+    for (var i=0;i<parent_node.children.length;i++)
+      parent_node.children[i].parentId = parent_node.id;
+
+    node.children = [parent_node];
+    parent_node.parentId = node.id;
+
+    // grand parent node loses parent_node as a child but gets node instead
+    for (var i=0;i<grandpa_children.length;i++)
+      if (grandpa_children[i].id!=parent_node.id)
+        grandpa_node.children.push ( grandpa_children[i] );
+    grandpa_node.children.push ( node );
+    node.parentId = grandpa_node.id;
+
+  }
+
+  // force selection and refresh the tree
+  if (this.created)  {
+    this.selectSingle ( node );  // force selection of the node if tree is displayed
+    $(this.root.element).jstree().refresh();
+    this.confirmCustomIconsVisibility();
+  }
+  */
+
+}
+
+
+Tree.prototype.deleteBranch = function ( node )  {
+// does not delete root node(s)
+
+  if (!node)
+    return;
+
+  if (!node.parentId)
+    return;
+
+  if (!(node.id in this.node_map))
+    return;
+
+  if (!(node.parentId in this.node_map))
+    return;
+
   this.deleteChildren ( node );
 
   var pnode    = this.node_map[node.parentId];
@@ -615,6 +1012,19 @@ Tree.prototype.createTree = function ( onReady_func,
           onSelect_func();
       });
 
+    $(tree.root.element).on("deselect_node.jstree",
+      function(evt,data) {
+        var snode = tree.calcSelectedNode();
+        if (snode)  {
+          if (tree.selected_node_id in tree.node_map)
+            tree.node_map[tree.selected_node_id].state.selected = false;
+          tree.selected_node_id = snode.id;
+          tree.node_map[tree.selected_node_id].state.selected = true;
+          if (onSelect_func)
+            onSelect_func();
+        }
+      });
+
     $(tree.root.element).on('open_node.jstree',function(evt,data){
       tree.node_map[data.node.id].state.opened = true;
     });
@@ -708,7 +1118,7 @@ var snode = this.getSelectedNode();
 Tree.prototype.deleteSelectedNode = function()  {
 var snode = this.getSelectedNode();
   if (snode)
-    this.deleteNode ( snode );
+    this.deleteBranch ( snode );
 }
 
 
@@ -724,6 +1134,6 @@ var selId = this.calcSelectedNodeId();
   for (var i=0;i<selId.length;i++)  {
     var snode = this.node_map[selId[i]];
     if (snode)
-      this.deleteNode ( snode );
+      this.deleteBranch ( snode );
   }
 }
